searchData={"items":[{"type":"module","title":"Bunt","doc":"`Bunt` enables 256 color ANSI coloring in the terminal and gives you the ability to alias colors to more semantic and application-specfic names.\n\n\n\n#","ref":"Bunt.html"},{"type":"module","title":"Augment `IO.ANSI` - Bunt","doc":"`IO.ANSI` provides an interface to write text to the terminal in eight different colors like this:\n\n    [\"Hello, \", :red, :bright, \"world!\"]\n    |> IO.ANSI.format\n    |> IO.puts\n\nThis will put the word \"world!\" in bright red.\n\nTo cause as little friction as possible, the interface of `Bunt.ANSI` is 100% adapted from `IO.ANSI`.\n\nWe can use `Bunt` in the same way:\n\n    [\"Hello, \", :color202, :bright, \"world!\"]\n    |> Bunt.ANSI.format\n    |> IO.puts\n\nwhich puts a bright orange-red `\"world!\"` on the screen.\n\n`Bunt` also provides a shortcut so we can skip the `format` call.\n\n    [\"Hello, \", :color202, :bright, \"world!\"]\n    |> Bunt.puts\n\nand since nobody can remember that `:color202` is basically `:orangered`, you can use `:orangered` directly.\n\n\n\n#","ref":"Bunt.html#module-augment-io-ansi"},{"type":"module","title":"Named colors - Bunt","doc":"The following colors were given names, so you can use them in style:\n\n    [:gold, \"Look, it's really gold text!\"]\n    |> Bunt.puts\n\nReplace `:gold` with any of these values:\n\n    darkblue      mediumblue    darkgreen     darkslategray darkcyan\n    deepskyblue   springgreen   aqua          dimgray       steelblue\n    darkred       darkmagenta   olive         chartreuse    aquamarine\n    greenyellow   chocolate     goldenrod     lightgray     beige\n    lightcyan     fuchsia       orangered     hotpink       darkorange\n    coral         orange        gold          khaki         moccasin\n    mistyrose     lightyellow\n\nYou can see all supported colors by cloning the repo and running:\n\n    $ mix run script/colors.exs\n\n#","ref":"Bunt.html#module-named-colors"},{"type":"module","title":"User-defined color aliases - Bunt","doc":"But since all these colors are hard to remember, you can alias them in your config.exs:\n\n    # I tend to start the names of my color aliases with an underscore\n    # but this is, naturally, not a must.\n\n    config :bunt, color_aliases: [_cupcake: :color205]\n\nThen you can use these keys instead of the standard colors in your code:\n\n    [:_cupcake, \"Hello World!\"]\n    |> Bunt.puts\n\nUse this to give your colors semantics. They get easier to change later that way. (A colleague of mine shouted \"It's CSS for console applications!\" when he saw this and although that is ... well, not true, I really like the sentiment! :+1:)","ref":"Bunt.html#module-user-defined-color-aliases"},{"type":"function","title":"Bunt.format/0","doc":"","ref":"Bunt.html#format/0"},{"type":"function","title":"Bunt.format/1","doc":"Formats `value` by converting named ANSI sequences into actual ANSI codes.","ref":"Bunt.html#format/1"},{"type":"function","title":"Examples - Bunt.format/1","doc":"Bunt.format([:bright, :cyan, \"Info!\"])","ref":"Bunt.html#format/1-examples"},{"type":"function","title":"Bunt.puts/1","doc":"Formats and writes `value` to `stdout`, similar to `write/1`, but adds a newline at the end.","ref":"Bunt.html#puts/1"},{"type":"function","title":"Examples - Bunt.puts/1","doc":"Bunt.puts([:bright, :green, \"Success!\"])","ref":"Bunt.html#puts/1-examples"},{"type":"function","title":"Bunt.version/0","doc":"Returns the version of Bunt.","ref":"Bunt.html#version/0"},{"type":"function","title":"Bunt.warn/1","doc":"Formats and writes `value` to `stderr`.","ref":"Bunt.html#warn/1"},{"type":"function","title":"Examples - Bunt.warn/1","doc":"Bunt.puts([:bright, :red, \"Warning!\"])","ref":"Bunt.html#warn/1-examples"},{"type":"function","title":"Bunt.write/1","doc":"Formats and writes `value` to `stdout`.","ref":"Bunt.html#write/1"},{"type":"function","title":"Examples - Bunt.write/1","doc":"Bunt.write([:bright, :cyan, \"Info!\"])","ref":"Bunt.html#write/1-examples"},{"type":"module","title":"Bunt.ANSI","doc":"Functionality to render ANSI escape sequences.\n\n[ANSI escape sequences](https://en.wikipedia.org/wiki/ANSI_escape_code)\nare characters embedded in text used to control formatting, color, and\nother output options on video text terminals.","ref":"Bunt.ANSI.html"},{"type":"function","title":"Bunt.ANSI.aqua/0","doc":"Sets foreground color to aqua","ref":"Bunt.ANSI.html#aqua/0"},{"type":"function","title":"Bunt.ANSI.aqua_background/0","doc":"Sets background color to aqua","ref":"Bunt.ANSI.html#aqua_background/0"},{"type":"function","title":"Bunt.ANSI.aquamarine/0","doc":"Sets foreground color to aquamarine","ref":"Bunt.ANSI.html#aquamarine/0"},{"type":"function","title":"Bunt.ANSI.aquamarine_background/0","doc":"Sets background color to aquamarine","ref":"Bunt.ANSI.html#aquamarine_background/0"},{"type":"function","title":"Bunt.ANSI.beige/0","doc":"Sets foreground color to beige","ref":"Bunt.ANSI.html#beige/0"},{"type":"function","title":"Bunt.ANSI.beige_background/0","doc":"Sets background color to beige","ref":"Bunt.ANSI.html#beige_background/0"},{"type":"function","title":"Bunt.ANSI.black/0","doc":"Sets foreground color to black","ref":"Bunt.ANSI.html#black/0"},{"type":"function","title":"Bunt.ANSI.black_background/0","doc":"Sets background color to black","ref":"Bunt.ANSI.html#black_background/0"},{"type":"function","title":"Bunt.ANSI.blink_off/0","doc":"Blink: off","ref":"Bunt.ANSI.html#blink_off/0"},{"type":"function","title":"Bunt.ANSI.blink_rapid/0","doc":"Blink: Rapid. MS-DOS ANSI.SYS; 150 per minute or more; not widely supported","ref":"Bunt.ANSI.html#blink_rapid/0"},{"type":"function","title":"Bunt.ANSI.blink_slow/0","doc":"Blink: Slow. Less than 150 per minute","ref":"Bunt.ANSI.html#blink_slow/0"},{"type":"function","title":"Bunt.ANSI.blue/0","doc":"Sets foreground color to blue","ref":"Bunt.ANSI.html#blue/0"},{"type":"function","title":"Bunt.ANSI.blue_background/0","doc":"Sets background color to blue","ref":"Bunt.ANSI.html#blue_background/0"},{"type":"function","title":"Bunt.ANSI.bright/0","doc":"Bright (increased intensity) or Bold","ref":"Bunt.ANSI.html#bright/0"},{"type":"function","title":"Bunt.ANSI.chartreuse/0","doc":"Sets foreground color to chartreuse","ref":"Bunt.ANSI.html#chartreuse/0"},{"type":"function","title":"Bunt.ANSI.chartreuse_background/0","doc":"Sets background color to chartreuse","ref":"Bunt.ANSI.html#chartreuse_background/0"},{"type":"function","title":"Bunt.ANSI.chocolate/0","doc":"Sets foreground color to chocolate","ref":"Bunt.ANSI.html#chocolate/0"},{"type":"function","title":"Bunt.ANSI.chocolate_background/0","doc":"Sets background color to chocolate","ref":"Bunt.ANSI.html#chocolate_background/0"},{"type":"function","title":"Bunt.ANSI.clear/0","doc":"Clears screen","ref":"Bunt.ANSI.html#clear/0"},{"type":"function","title":"Bunt.ANSI.clear_line/0","doc":"Clears line","ref":"Bunt.ANSI.html#clear_line/0"},{"type":"function","title":"Bunt.ANSI.color16/0","doc":"Sets foreground color to color16","ref":"Bunt.ANSI.html#color16/0"},{"type":"function","title":"Bunt.ANSI.color16_background/0","doc":"Sets background color to color16","ref":"Bunt.ANSI.html#color16_background/0"},{"type":"function","title":"Bunt.ANSI.color17/0","doc":"Sets foreground color to color17","ref":"Bunt.ANSI.html#color17/0"},{"type":"function","title":"Bunt.ANSI.color17_background/0","doc":"Sets background color to color17","ref":"Bunt.ANSI.html#color17_background/0"},{"type":"function","title":"Bunt.ANSI.color18/0","doc":"Sets foreground color to color18","ref":"Bunt.ANSI.html#color18/0"},{"type":"function","title":"Bunt.ANSI.color18_background/0","doc":"Sets background color to color18","ref":"Bunt.ANSI.html#color18_background/0"},{"type":"function","title":"Bunt.ANSI.color19/0","doc":"Sets foreground color to color19","ref":"Bunt.ANSI.html#color19/0"},{"type":"function","title":"Bunt.ANSI.color19_background/0","doc":"Sets background color to color19","ref":"Bunt.ANSI.html#color19_background/0"},{"type":"function","title":"Bunt.ANSI.color20/0","doc":"Sets foreground color to color20","ref":"Bunt.ANSI.html#color20/0"},{"type":"function","title":"Bunt.ANSI.color20_background/0","doc":"Sets background color to color20","ref":"Bunt.ANSI.html#color20_background/0"},{"type":"function","title":"Bunt.ANSI.color21/0","doc":"Sets foreground color to color21","ref":"Bunt.ANSI.html#color21/0"},{"type":"function","title":"Bunt.ANSI.color21_background/0","doc":"Sets background color to color21","ref":"Bunt.ANSI.html#color21_background/0"},{"type":"function","title":"Bunt.ANSI.color22/0","doc":"Sets foreground color to color22","ref":"Bunt.ANSI.html#color22/0"},{"type":"function","title":"Bunt.ANSI.color22_background/0","doc":"Sets background color to color22","ref":"Bunt.ANSI.html#color22_background/0"},{"type":"function","title":"Bunt.ANSI.color23/0","doc":"Sets foreground color to color23","ref":"Bunt.ANSI.html#color23/0"},{"type":"function","title":"Bunt.ANSI.color23_background/0","doc":"Sets background color to color23","ref":"Bunt.ANSI.html#color23_background/0"},{"type":"function","title":"Bunt.ANSI.color24/0","doc":"Sets foreground color to color24","ref":"Bunt.ANSI.html#color24/0"},{"type":"function","title":"Bunt.ANSI.color24_background/0","doc":"Sets background color to color24","ref":"Bunt.ANSI.html#color24_background/0"},{"type":"function","title":"Bunt.ANSI.color25/0","doc":"Sets foreground color to color25","ref":"Bunt.ANSI.html#color25/0"},{"type":"function","title":"Bunt.ANSI.color25_background/0","doc":"Sets background color to color25","ref":"Bunt.ANSI.html#color25_background/0"},{"type":"function","title":"Bunt.ANSI.color26/0","doc":"Sets foreground color to color26","ref":"Bunt.ANSI.html#color26/0"},{"type":"function","title":"Bunt.ANSI.color26_background/0","doc":"Sets background color to color26","ref":"Bunt.ANSI.html#color26_background/0"},{"type":"function","title":"Bunt.ANSI.color27/0","doc":"Sets foreground color to color27","ref":"Bunt.ANSI.html#color27/0"},{"type":"function","title":"Bunt.ANSI.color27_background/0","doc":"Sets background color to color27","ref":"Bunt.ANSI.html#color27_background/0"},{"type":"function","title":"Bunt.ANSI.color28/0","doc":"Sets foreground color to color28","ref":"Bunt.ANSI.html#color28/0"},{"type":"function","title":"Bunt.ANSI.color28_background/0","doc":"Sets background color to color28","ref":"Bunt.ANSI.html#color28_background/0"},{"type":"function","title":"Bunt.ANSI.color29/0","doc":"Sets foreground color to color29","ref":"Bunt.ANSI.html#color29/0"},{"type":"function","title":"Bunt.ANSI.color29_background/0","doc":"Sets background color to color29","ref":"Bunt.ANSI.html#color29_background/0"},{"type":"function","title":"Bunt.ANSI.color30/0","doc":"Sets foreground color to color30","ref":"Bunt.ANSI.html#color30/0"},{"type":"function","title":"Bunt.ANSI.color30_background/0","doc":"Sets background color to color30","ref":"Bunt.ANSI.html#color30_background/0"},{"type":"function","title":"Bunt.ANSI.color31/0","doc":"Sets foreground color to color31","ref":"Bunt.ANSI.html#color31/0"},{"type":"function","title":"Bunt.ANSI.color31_background/0","doc":"Sets background color to color31","ref":"Bunt.ANSI.html#color31_background/0"},{"type":"function","title":"Bunt.ANSI.color32/0","doc":"Sets foreground color to color32","ref":"Bunt.ANSI.html#color32/0"},{"type":"function","title":"Bunt.ANSI.color32_background/0","doc":"Sets background color to color32","ref":"Bunt.ANSI.html#color32_background/0"},{"type":"function","title":"Bunt.ANSI.color33/0","doc":"Sets foreground color to color33","ref":"Bunt.ANSI.html#color33/0"},{"type":"function","title":"Bunt.ANSI.color33_background/0","doc":"Sets background color to color33","ref":"Bunt.ANSI.html#color33_background/0"},{"type":"function","title":"Bunt.ANSI.color34/0","doc":"Sets foreground color to color34","ref":"Bunt.ANSI.html#color34/0"},{"type":"function","title":"Bunt.ANSI.color34_background/0","doc":"Sets background color to color34","ref":"Bunt.ANSI.html#color34_background/0"},{"type":"function","title":"Bunt.ANSI.color35/0","doc":"Sets foreground color to color35","ref":"Bunt.ANSI.html#color35/0"},{"type":"function","title":"Bunt.ANSI.color35_background/0","doc":"Sets background color to color35","ref":"Bunt.ANSI.html#color35_background/0"},{"type":"function","title":"Bunt.ANSI.color36/0","doc":"Sets foreground color to color36","ref":"Bunt.ANSI.html#color36/0"},{"type":"function","title":"Bunt.ANSI.color36_background/0","doc":"Sets background color to color36","ref":"Bunt.ANSI.html#color36_background/0"},{"type":"function","title":"Bunt.ANSI.color37/0","doc":"Sets foreground color to color37","ref":"Bunt.ANSI.html#color37/0"},{"type":"function","title":"Bunt.ANSI.color37_background/0","doc":"Sets background color to color37","ref":"Bunt.ANSI.html#color37_background/0"},{"type":"function","title":"Bunt.ANSI.color38/0","doc":"Sets foreground color to color38","ref":"Bunt.ANSI.html#color38/0"},{"type":"function","title":"Bunt.ANSI.color38_background/0","doc":"Sets background color to color38","ref":"Bunt.ANSI.html#color38_background/0"},{"type":"function","title":"Bunt.ANSI.color39/0","doc":"Sets foreground color to color39","ref":"Bunt.ANSI.html#color39/0"},{"type":"function","title":"Bunt.ANSI.color39_background/0","doc":"Sets background color to color39","ref":"Bunt.ANSI.html#color39_background/0"},{"type":"function","title":"Bunt.ANSI.color40/0","doc":"Sets foreground color to color40","ref":"Bunt.ANSI.html#color40/0"},{"type":"function","title":"Bunt.ANSI.color40_background/0","doc":"Sets background color to color40","ref":"Bunt.ANSI.html#color40_background/0"},{"type":"function","title":"Bunt.ANSI.color41/0","doc":"Sets foreground color to color41","ref":"Bunt.ANSI.html#color41/0"},{"type":"function","title":"Bunt.ANSI.color41_background/0","doc":"Sets background color to color41","ref":"Bunt.ANSI.html#color41_background/0"},{"type":"function","title":"Bunt.ANSI.color42/0","doc":"Sets foreground color to color42","ref":"Bunt.ANSI.html#color42/0"},{"type":"function","title":"Bunt.ANSI.color42_background/0","doc":"Sets background color to color42","ref":"Bunt.ANSI.html#color42_background/0"},{"type":"function","title":"Bunt.ANSI.color43/0","doc":"Sets foreground color to color43","ref":"Bunt.ANSI.html#color43/0"},{"type":"function","title":"Bunt.ANSI.color43_background/0","doc":"Sets background color to color43","ref":"Bunt.ANSI.html#color43_background/0"},{"type":"function","title":"Bunt.ANSI.color44/0","doc":"Sets foreground color to color44","ref":"Bunt.ANSI.html#color44/0"},{"type":"function","title":"Bunt.ANSI.color44_background/0","doc":"Sets background color to color44","ref":"Bunt.ANSI.html#color44_background/0"},{"type":"function","title":"Bunt.ANSI.color45/0","doc":"Sets foreground color to color45","ref":"Bunt.ANSI.html#color45/0"},{"type":"function","title":"Bunt.ANSI.color45_background/0","doc":"Sets background color to color45","ref":"Bunt.ANSI.html#color45_background/0"},{"type":"function","title":"Bunt.ANSI.color46/0","doc":"Sets foreground color to color46","ref":"Bunt.ANSI.html#color46/0"},{"type":"function","title":"Bunt.ANSI.color46_background/0","doc":"Sets background color to color46","ref":"Bunt.ANSI.html#color46_background/0"},{"type":"function","title":"Bunt.ANSI.color47/0","doc":"Sets foreground color to color47","ref":"Bunt.ANSI.html#color47/0"},{"type":"function","title":"Bunt.ANSI.color47_background/0","doc":"Sets background color to color47","ref":"Bunt.ANSI.html#color47_background/0"},{"type":"function","title":"Bunt.ANSI.color48/0","doc":"Sets foreground color to color48","ref":"Bunt.ANSI.html#color48/0"},{"type":"function","title":"Bunt.ANSI.color48_background/0","doc":"Sets background color to color48","ref":"Bunt.ANSI.html#color48_background/0"},{"type":"function","title":"Bunt.ANSI.color49/0","doc":"Sets foreground color to color49","ref":"Bunt.ANSI.html#color49/0"},{"type":"function","title":"Bunt.ANSI.color49_background/0","doc":"Sets background color to color49","ref":"Bunt.ANSI.html#color49_background/0"},{"type":"function","title":"Bunt.ANSI.color50/0","doc":"Sets foreground color to color50","ref":"Bunt.ANSI.html#color50/0"},{"type":"function","title":"Bunt.ANSI.color50_background/0","doc":"Sets background color to color50","ref":"Bunt.ANSI.html#color50_background/0"},{"type":"function","title":"Bunt.ANSI.color51/0","doc":"Sets foreground color to color51","ref":"Bunt.ANSI.html#color51/0"},{"type":"function","title":"Bunt.ANSI.color51_background/0","doc":"Sets background color to color51","ref":"Bunt.ANSI.html#color51_background/0"},{"type":"function","title":"Bunt.ANSI.color52/0","doc":"Sets foreground color to color52","ref":"Bunt.ANSI.html#color52/0"},{"type":"function","title":"Bunt.ANSI.color52_background/0","doc":"Sets background color to color52","ref":"Bunt.ANSI.html#color52_background/0"},{"type":"function","title":"Bunt.ANSI.color53/0","doc":"Sets foreground color to color53","ref":"Bunt.ANSI.html#color53/0"},{"type":"function","title":"Bunt.ANSI.color53_background/0","doc":"Sets background color to color53","ref":"Bunt.ANSI.html#color53_background/0"},{"type":"function","title":"Bunt.ANSI.color54/0","doc":"Sets foreground color to color54","ref":"Bunt.ANSI.html#color54/0"},{"type":"function","title":"Bunt.ANSI.color54_background/0","doc":"Sets background color to color54","ref":"Bunt.ANSI.html#color54_background/0"},{"type":"function","title":"Bunt.ANSI.color55/0","doc":"Sets foreground color to color55","ref":"Bunt.ANSI.html#color55/0"},{"type":"function","title":"Bunt.ANSI.color55_background/0","doc":"Sets background color to color55","ref":"Bunt.ANSI.html#color55_background/0"},{"type":"function","title":"Bunt.ANSI.color56/0","doc":"Sets foreground color to color56","ref":"Bunt.ANSI.html#color56/0"},{"type":"function","title":"Bunt.ANSI.color56_background/0","doc":"Sets background color to color56","ref":"Bunt.ANSI.html#color56_background/0"},{"type":"function","title":"Bunt.ANSI.color57/0","doc":"Sets foreground color to color57","ref":"Bunt.ANSI.html#color57/0"},{"type":"function","title":"Bunt.ANSI.color57_background/0","doc":"Sets background color to color57","ref":"Bunt.ANSI.html#color57_background/0"},{"type":"function","title":"Bunt.ANSI.color58/0","doc":"Sets foreground color to color58","ref":"Bunt.ANSI.html#color58/0"},{"type":"function","title":"Bunt.ANSI.color58_background/0","doc":"Sets background color to color58","ref":"Bunt.ANSI.html#color58_background/0"},{"type":"function","title":"Bunt.ANSI.color59/0","doc":"Sets foreground color to color59","ref":"Bunt.ANSI.html#color59/0"},{"type":"function","title":"Bunt.ANSI.color59_background/0","doc":"Sets background color to color59","ref":"Bunt.ANSI.html#color59_background/0"},{"type":"function","title":"Bunt.ANSI.color60/0","doc":"Sets foreground color to color60","ref":"Bunt.ANSI.html#color60/0"},{"type":"function","title":"Bunt.ANSI.color60_background/0","doc":"Sets background color to color60","ref":"Bunt.ANSI.html#color60_background/0"},{"type":"function","title":"Bunt.ANSI.color61/0","doc":"Sets foreground color to color61","ref":"Bunt.ANSI.html#color61/0"},{"type":"function","title":"Bunt.ANSI.color61_background/0","doc":"Sets background color to color61","ref":"Bunt.ANSI.html#color61_background/0"},{"type":"function","title":"Bunt.ANSI.color62/0","doc":"Sets foreground color to color62","ref":"Bunt.ANSI.html#color62/0"},{"type":"function","title":"Bunt.ANSI.color62_background/0","doc":"Sets background color to color62","ref":"Bunt.ANSI.html#color62_background/0"},{"type":"function","title":"Bunt.ANSI.color63/0","doc":"Sets foreground color to color63","ref":"Bunt.ANSI.html#color63/0"},{"type":"function","title":"Bunt.ANSI.color63_background/0","doc":"Sets background color to color63","ref":"Bunt.ANSI.html#color63_background/0"},{"type":"function","title":"Bunt.ANSI.color64/0","doc":"Sets foreground color to color64","ref":"Bunt.ANSI.html#color64/0"},{"type":"function","title":"Bunt.ANSI.color64_background/0","doc":"Sets background color to color64","ref":"Bunt.ANSI.html#color64_background/0"},{"type":"function","title":"Bunt.ANSI.color65/0","doc":"Sets foreground color to color65","ref":"Bunt.ANSI.html#color65/0"},{"type":"function","title":"Bunt.ANSI.color65_background/0","doc":"Sets background color to color65","ref":"Bunt.ANSI.html#color65_background/0"},{"type":"function","title":"Bunt.ANSI.color66/0","doc":"Sets foreground color to color66","ref":"Bunt.ANSI.html#color66/0"},{"type":"function","title":"Bunt.ANSI.color66_background/0","doc":"Sets background color to color66","ref":"Bunt.ANSI.html#color66_background/0"},{"type":"function","title":"Bunt.ANSI.color67/0","doc":"Sets foreground color to color67","ref":"Bunt.ANSI.html#color67/0"},{"type":"function","title":"Bunt.ANSI.color67_background/0","doc":"Sets background color to color67","ref":"Bunt.ANSI.html#color67_background/0"},{"type":"function","title":"Bunt.ANSI.color68/0","doc":"Sets foreground color to color68","ref":"Bunt.ANSI.html#color68/0"},{"type":"function","title":"Bunt.ANSI.color68_background/0","doc":"Sets background color to color68","ref":"Bunt.ANSI.html#color68_background/0"},{"type":"function","title":"Bunt.ANSI.color69/0","doc":"Sets foreground color to color69","ref":"Bunt.ANSI.html#color69/0"},{"type":"function","title":"Bunt.ANSI.color69_background/0","doc":"Sets background color to color69","ref":"Bunt.ANSI.html#color69_background/0"},{"type":"function","title":"Bunt.ANSI.color70/0","doc":"Sets foreground color to color70","ref":"Bunt.ANSI.html#color70/0"},{"type":"function","title":"Bunt.ANSI.color70_background/0","doc":"Sets background color to color70","ref":"Bunt.ANSI.html#color70_background/0"},{"type":"function","title":"Bunt.ANSI.color71/0","doc":"Sets foreground color to color71","ref":"Bunt.ANSI.html#color71/0"},{"type":"function","title":"Bunt.ANSI.color71_background/0","doc":"Sets background color to color71","ref":"Bunt.ANSI.html#color71_background/0"},{"type":"function","title":"Bunt.ANSI.color72/0","doc":"Sets foreground color to color72","ref":"Bunt.ANSI.html#color72/0"},{"type":"function","title":"Bunt.ANSI.color72_background/0","doc":"Sets background color to color72","ref":"Bunt.ANSI.html#color72_background/0"},{"type":"function","title":"Bunt.ANSI.color73/0","doc":"Sets foreground color to color73","ref":"Bunt.ANSI.html#color73/0"},{"type":"function","title":"Bunt.ANSI.color73_background/0","doc":"Sets background color to color73","ref":"Bunt.ANSI.html#color73_background/0"},{"type":"function","title":"Bunt.ANSI.color74/0","doc":"Sets foreground color to color74","ref":"Bunt.ANSI.html#color74/0"},{"type":"function","title":"Bunt.ANSI.color74_background/0","doc":"Sets background color to color74","ref":"Bunt.ANSI.html#color74_background/0"},{"type":"function","title":"Bunt.ANSI.color75/0","doc":"Sets foreground color to color75","ref":"Bunt.ANSI.html#color75/0"},{"type":"function","title":"Bunt.ANSI.color75_background/0","doc":"Sets background color to color75","ref":"Bunt.ANSI.html#color75_background/0"},{"type":"function","title":"Bunt.ANSI.color76/0","doc":"Sets foreground color to color76","ref":"Bunt.ANSI.html#color76/0"},{"type":"function","title":"Bunt.ANSI.color76_background/0","doc":"Sets background color to color76","ref":"Bunt.ANSI.html#color76_background/0"},{"type":"function","title":"Bunt.ANSI.color77/0","doc":"Sets foreground color to color77","ref":"Bunt.ANSI.html#color77/0"},{"type":"function","title":"Bunt.ANSI.color77_background/0","doc":"Sets background color to color77","ref":"Bunt.ANSI.html#color77_background/0"},{"type":"function","title":"Bunt.ANSI.color78/0","doc":"Sets foreground color to color78","ref":"Bunt.ANSI.html#color78/0"},{"type":"function","title":"Bunt.ANSI.color78_background/0","doc":"Sets background color to color78","ref":"Bunt.ANSI.html#color78_background/0"},{"type":"function","title":"Bunt.ANSI.color79/0","doc":"Sets foreground color to color79","ref":"Bunt.ANSI.html#color79/0"},{"type":"function","title":"Bunt.ANSI.color79_background/0","doc":"Sets background color to color79","ref":"Bunt.ANSI.html#color79_background/0"},{"type":"function","title":"Bunt.ANSI.color80/0","doc":"Sets foreground color to color80","ref":"Bunt.ANSI.html#color80/0"},{"type":"function","title":"Bunt.ANSI.color80_background/0","doc":"Sets background color to color80","ref":"Bunt.ANSI.html#color80_background/0"},{"type":"function","title":"Bunt.ANSI.color81/0","doc":"Sets foreground color to color81","ref":"Bunt.ANSI.html#color81/0"},{"type":"function","title":"Bunt.ANSI.color81_background/0","doc":"Sets background color to color81","ref":"Bunt.ANSI.html#color81_background/0"},{"type":"function","title":"Bunt.ANSI.color82/0","doc":"Sets foreground color to color82","ref":"Bunt.ANSI.html#color82/0"},{"type":"function","title":"Bunt.ANSI.color82_background/0","doc":"Sets background color to color82","ref":"Bunt.ANSI.html#color82_background/0"},{"type":"function","title":"Bunt.ANSI.color83/0","doc":"Sets foreground color to color83","ref":"Bunt.ANSI.html#color83/0"},{"type":"function","title":"Bunt.ANSI.color83_background/0","doc":"Sets background color to color83","ref":"Bunt.ANSI.html#color83_background/0"},{"type":"function","title":"Bunt.ANSI.color84/0","doc":"Sets foreground color to color84","ref":"Bunt.ANSI.html#color84/0"},{"type":"function","title":"Bunt.ANSI.color84_background/0","doc":"Sets background color to color84","ref":"Bunt.ANSI.html#color84_background/0"},{"type":"function","title":"Bunt.ANSI.color85/0","doc":"Sets foreground color to color85","ref":"Bunt.ANSI.html#color85/0"},{"type":"function","title":"Bunt.ANSI.color85_background/0","doc":"Sets background color to color85","ref":"Bunt.ANSI.html#color85_background/0"},{"type":"function","title":"Bunt.ANSI.color86/0","doc":"Sets foreground color to color86","ref":"Bunt.ANSI.html#color86/0"},{"type":"function","title":"Bunt.ANSI.color86_background/0","doc":"Sets background color to color86","ref":"Bunt.ANSI.html#color86_background/0"},{"type":"function","title":"Bunt.ANSI.color87/0","doc":"Sets foreground color to color87","ref":"Bunt.ANSI.html#color87/0"},{"type":"function","title":"Bunt.ANSI.color87_background/0","doc":"Sets background color to color87","ref":"Bunt.ANSI.html#color87_background/0"},{"type":"function","title":"Bunt.ANSI.color88/0","doc":"Sets foreground color to color88","ref":"Bunt.ANSI.html#color88/0"},{"type":"function","title":"Bunt.ANSI.color88_background/0","doc":"Sets background color to color88","ref":"Bunt.ANSI.html#color88_background/0"},{"type":"function","title":"Bunt.ANSI.color89/0","doc":"Sets foreground color to color89","ref":"Bunt.ANSI.html#color89/0"},{"type":"function","title":"Bunt.ANSI.color89_background/0","doc":"Sets background color to color89","ref":"Bunt.ANSI.html#color89_background/0"},{"type":"function","title":"Bunt.ANSI.color90/0","doc":"Sets foreground color to color90","ref":"Bunt.ANSI.html#color90/0"},{"type":"function","title":"Bunt.ANSI.color90_background/0","doc":"Sets background color to color90","ref":"Bunt.ANSI.html#color90_background/0"},{"type":"function","title":"Bunt.ANSI.color91/0","doc":"Sets foreground color to color91","ref":"Bunt.ANSI.html#color91/0"},{"type":"function","title":"Bunt.ANSI.color91_background/0","doc":"Sets background color to color91","ref":"Bunt.ANSI.html#color91_background/0"},{"type":"function","title":"Bunt.ANSI.color92/0","doc":"Sets foreground color to color92","ref":"Bunt.ANSI.html#color92/0"},{"type":"function","title":"Bunt.ANSI.color92_background/0","doc":"Sets background color to color92","ref":"Bunt.ANSI.html#color92_background/0"},{"type":"function","title":"Bunt.ANSI.color93/0","doc":"Sets foreground color to color93","ref":"Bunt.ANSI.html#color93/0"},{"type":"function","title":"Bunt.ANSI.color93_background/0","doc":"Sets background color to color93","ref":"Bunt.ANSI.html#color93_background/0"},{"type":"function","title":"Bunt.ANSI.color94/0","doc":"Sets foreground color to color94","ref":"Bunt.ANSI.html#color94/0"},{"type":"function","title":"Bunt.ANSI.color94_background/0","doc":"Sets background color to color94","ref":"Bunt.ANSI.html#color94_background/0"},{"type":"function","title":"Bunt.ANSI.color95/0","doc":"Sets foreground color to color95","ref":"Bunt.ANSI.html#color95/0"},{"type":"function","title":"Bunt.ANSI.color95_background/0","doc":"Sets background color to color95","ref":"Bunt.ANSI.html#color95_background/0"},{"type":"function","title":"Bunt.ANSI.color96/0","doc":"Sets foreground color to color96","ref":"Bunt.ANSI.html#color96/0"},{"type":"function","title":"Bunt.ANSI.color96_background/0","doc":"Sets background color to color96","ref":"Bunt.ANSI.html#color96_background/0"},{"type":"function","title":"Bunt.ANSI.color97/0","doc":"Sets foreground color to color97","ref":"Bunt.ANSI.html#color97/0"},{"type":"function","title":"Bunt.ANSI.color97_background/0","doc":"Sets background color to color97","ref":"Bunt.ANSI.html#color97_background/0"},{"type":"function","title":"Bunt.ANSI.color98/0","doc":"Sets foreground color to color98","ref":"Bunt.ANSI.html#color98/0"},{"type":"function","title":"Bunt.ANSI.color98_background/0","doc":"Sets background color to color98","ref":"Bunt.ANSI.html#color98_background/0"},{"type":"function","title":"Bunt.ANSI.color99/0","doc":"Sets foreground color to color99","ref":"Bunt.ANSI.html#color99/0"},{"type":"function","title":"Bunt.ANSI.color99_background/0","doc":"Sets background color to color99","ref":"Bunt.ANSI.html#color99_background/0"},{"type":"function","title":"Bunt.ANSI.color100/0","doc":"Sets foreground color to color100","ref":"Bunt.ANSI.html#color100/0"},{"type":"function","title":"Bunt.ANSI.color100_background/0","doc":"Sets background color to color100","ref":"Bunt.ANSI.html#color100_background/0"},{"type":"function","title":"Bunt.ANSI.color101/0","doc":"Sets foreground color to color101","ref":"Bunt.ANSI.html#color101/0"},{"type":"function","title":"Bunt.ANSI.color101_background/0","doc":"Sets background color to color101","ref":"Bunt.ANSI.html#color101_background/0"},{"type":"function","title":"Bunt.ANSI.color102/0","doc":"Sets foreground color to color102","ref":"Bunt.ANSI.html#color102/0"},{"type":"function","title":"Bunt.ANSI.color102_background/0","doc":"Sets background color to color102","ref":"Bunt.ANSI.html#color102_background/0"},{"type":"function","title":"Bunt.ANSI.color103/0","doc":"Sets foreground color to color103","ref":"Bunt.ANSI.html#color103/0"},{"type":"function","title":"Bunt.ANSI.color103_background/0","doc":"Sets background color to color103","ref":"Bunt.ANSI.html#color103_background/0"},{"type":"function","title":"Bunt.ANSI.color104/0","doc":"Sets foreground color to color104","ref":"Bunt.ANSI.html#color104/0"},{"type":"function","title":"Bunt.ANSI.color104_background/0","doc":"Sets background color to color104","ref":"Bunt.ANSI.html#color104_background/0"},{"type":"function","title":"Bunt.ANSI.color105/0","doc":"Sets foreground color to color105","ref":"Bunt.ANSI.html#color105/0"},{"type":"function","title":"Bunt.ANSI.color105_background/0","doc":"Sets background color to color105","ref":"Bunt.ANSI.html#color105_background/0"},{"type":"function","title":"Bunt.ANSI.color106/0","doc":"Sets foreground color to color106","ref":"Bunt.ANSI.html#color106/0"},{"type":"function","title":"Bunt.ANSI.color106_background/0","doc":"Sets background color to color106","ref":"Bunt.ANSI.html#color106_background/0"},{"type":"function","title":"Bunt.ANSI.color107/0","doc":"Sets foreground color to color107","ref":"Bunt.ANSI.html#color107/0"},{"type":"function","title":"Bunt.ANSI.color107_background/0","doc":"Sets background color to color107","ref":"Bunt.ANSI.html#color107_background/0"},{"type":"function","title":"Bunt.ANSI.color108/0","doc":"Sets foreground color to color108","ref":"Bunt.ANSI.html#color108/0"},{"type":"function","title":"Bunt.ANSI.color108_background/0","doc":"Sets background color to color108","ref":"Bunt.ANSI.html#color108_background/0"},{"type":"function","title":"Bunt.ANSI.color109/0","doc":"Sets foreground color to color109","ref":"Bunt.ANSI.html#color109/0"},{"type":"function","title":"Bunt.ANSI.color109_background/0","doc":"Sets background color to color109","ref":"Bunt.ANSI.html#color109_background/0"},{"type":"function","title":"Bunt.ANSI.color110/0","doc":"Sets foreground color to color110","ref":"Bunt.ANSI.html#color110/0"},{"type":"function","title":"Bunt.ANSI.color110_background/0","doc":"Sets background color to color110","ref":"Bunt.ANSI.html#color110_background/0"},{"type":"function","title":"Bunt.ANSI.color111/0","doc":"Sets foreground color to color111","ref":"Bunt.ANSI.html#color111/0"},{"type":"function","title":"Bunt.ANSI.color111_background/0","doc":"Sets background color to color111","ref":"Bunt.ANSI.html#color111_background/0"},{"type":"function","title":"Bunt.ANSI.color112/0","doc":"Sets foreground color to color112","ref":"Bunt.ANSI.html#color112/0"},{"type":"function","title":"Bunt.ANSI.color112_background/0","doc":"Sets background color to color112","ref":"Bunt.ANSI.html#color112_background/0"},{"type":"function","title":"Bunt.ANSI.color113/0","doc":"Sets foreground color to color113","ref":"Bunt.ANSI.html#color113/0"},{"type":"function","title":"Bunt.ANSI.color113_background/0","doc":"Sets background color to color113","ref":"Bunt.ANSI.html#color113_background/0"},{"type":"function","title":"Bunt.ANSI.color114/0","doc":"Sets foreground color to color114","ref":"Bunt.ANSI.html#color114/0"},{"type":"function","title":"Bunt.ANSI.color114_background/0","doc":"Sets background color to color114","ref":"Bunt.ANSI.html#color114_background/0"},{"type":"function","title":"Bunt.ANSI.color115/0","doc":"Sets foreground color to color115","ref":"Bunt.ANSI.html#color115/0"},{"type":"function","title":"Bunt.ANSI.color115_background/0","doc":"Sets background color to color115","ref":"Bunt.ANSI.html#color115_background/0"},{"type":"function","title":"Bunt.ANSI.color116/0","doc":"Sets foreground color to color116","ref":"Bunt.ANSI.html#color116/0"},{"type":"function","title":"Bunt.ANSI.color116_background/0","doc":"Sets background color to color116","ref":"Bunt.ANSI.html#color116_background/0"},{"type":"function","title":"Bunt.ANSI.color117/0","doc":"Sets foreground color to color117","ref":"Bunt.ANSI.html#color117/0"},{"type":"function","title":"Bunt.ANSI.color117_background/0","doc":"Sets background color to color117","ref":"Bunt.ANSI.html#color117_background/0"},{"type":"function","title":"Bunt.ANSI.color118/0","doc":"Sets foreground color to color118","ref":"Bunt.ANSI.html#color118/0"},{"type":"function","title":"Bunt.ANSI.color118_background/0","doc":"Sets background color to color118","ref":"Bunt.ANSI.html#color118_background/0"},{"type":"function","title":"Bunt.ANSI.color119/0","doc":"Sets foreground color to color119","ref":"Bunt.ANSI.html#color119/0"},{"type":"function","title":"Bunt.ANSI.color119_background/0","doc":"Sets background color to color119","ref":"Bunt.ANSI.html#color119_background/0"},{"type":"function","title":"Bunt.ANSI.color120/0","doc":"Sets foreground color to color120","ref":"Bunt.ANSI.html#color120/0"},{"type":"function","title":"Bunt.ANSI.color120_background/0","doc":"Sets background color to color120","ref":"Bunt.ANSI.html#color120_background/0"},{"type":"function","title":"Bunt.ANSI.color121/0","doc":"Sets foreground color to color121","ref":"Bunt.ANSI.html#color121/0"},{"type":"function","title":"Bunt.ANSI.color121_background/0","doc":"Sets background color to color121","ref":"Bunt.ANSI.html#color121_background/0"},{"type":"function","title":"Bunt.ANSI.color122/0","doc":"Sets foreground color to color122","ref":"Bunt.ANSI.html#color122/0"},{"type":"function","title":"Bunt.ANSI.color122_background/0","doc":"Sets background color to color122","ref":"Bunt.ANSI.html#color122_background/0"},{"type":"function","title":"Bunt.ANSI.color123/0","doc":"Sets foreground color to color123","ref":"Bunt.ANSI.html#color123/0"},{"type":"function","title":"Bunt.ANSI.color123_background/0","doc":"Sets background color to color123","ref":"Bunt.ANSI.html#color123_background/0"},{"type":"function","title":"Bunt.ANSI.color124/0","doc":"Sets foreground color to color124","ref":"Bunt.ANSI.html#color124/0"},{"type":"function","title":"Bunt.ANSI.color124_background/0","doc":"Sets background color to color124","ref":"Bunt.ANSI.html#color124_background/0"},{"type":"function","title":"Bunt.ANSI.color125/0","doc":"Sets foreground color to color125","ref":"Bunt.ANSI.html#color125/0"},{"type":"function","title":"Bunt.ANSI.color125_background/0","doc":"Sets background color to color125","ref":"Bunt.ANSI.html#color125_background/0"},{"type":"function","title":"Bunt.ANSI.color126/0","doc":"Sets foreground color to color126","ref":"Bunt.ANSI.html#color126/0"},{"type":"function","title":"Bunt.ANSI.color126_background/0","doc":"Sets background color to color126","ref":"Bunt.ANSI.html#color126_background/0"},{"type":"function","title":"Bunt.ANSI.color127/0","doc":"Sets foreground color to color127","ref":"Bunt.ANSI.html#color127/0"},{"type":"function","title":"Bunt.ANSI.color127_background/0","doc":"Sets background color to color127","ref":"Bunt.ANSI.html#color127_background/0"},{"type":"function","title":"Bunt.ANSI.color128/0","doc":"Sets foreground color to color128","ref":"Bunt.ANSI.html#color128/0"},{"type":"function","title":"Bunt.ANSI.color128_background/0","doc":"Sets background color to color128","ref":"Bunt.ANSI.html#color128_background/0"},{"type":"function","title":"Bunt.ANSI.color129/0","doc":"Sets foreground color to color129","ref":"Bunt.ANSI.html#color129/0"},{"type":"function","title":"Bunt.ANSI.color129_background/0","doc":"Sets background color to color129","ref":"Bunt.ANSI.html#color129_background/0"},{"type":"function","title":"Bunt.ANSI.color130/0","doc":"Sets foreground color to color130","ref":"Bunt.ANSI.html#color130/0"},{"type":"function","title":"Bunt.ANSI.color130_background/0","doc":"Sets background color to color130","ref":"Bunt.ANSI.html#color130_background/0"},{"type":"function","title":"Bunt.ANSI.color131/0","doc":"Sets foreground color to color131","ref":"Bunt.ANSI.html#color131/0"},{"type":"function","title":"Bunt.ANSI.color131_background/0","doc":"Sets background color to color131","ref":"Bunt.ANSI.html#color131_background/0"},{"type":"function","title":"Bunt.ANSI.color132/0","doc":"Sets foreground color to color132","ref":"Bunt.ANSI.html#color132/0"},{"type":"function","title":"Bunt.ANSI.color132_background/0","doc":"Sets background color to color132","ref":"Bunt.ANSI.html#color132_background/0"},{"type":"function","title":"Bunt.ANSI.color133/0","doc":"Sets foreground color to color133","ref":"Bunt.ANSI.html#color133/0"},{"type":"function","title":"Bunt.ANSI.color133_background/0","doc":"Sets background color to color133","ref":"Bunt.ANSI.html#color133_background/0"},{"type":"function","title":"Bunt.ANSI.color134/0","doc":"Sets foreground color to color134","ref":"Bunt.ANSI.html#color134/0"},{"type":"function","title":"Bunt.ANSI.color134_background/0","doc":"Sets background color to color134","ref":"Bunt.ANSI.html#color134_background/0"},{"type":"function","title":"Bunt.ANSI.color135/0","doc":"Sets foreground color to color135","ref":"Bunt.ANSI.html#color135/0"},{"type":"function","title":"Bunt.ANSI.color135_background/0","doc":"Sets background color to color135","ref":"Bunt.ANSI.html#color135_background/0"},{"type":"function","title":"Bunt.ANSI.color136/0","doc":"Sets foreground color to color136","ref":"Bunt.ANSI.html#color136/0"},{"type":"function","title":"Bunt.ANSI.color136_background/0","doc":"Sets background color to color136","ref":"Bunt.ANSI.html#color136_background/0"},{"type":"function","title":"Bunt.ANSI.color137/0","doc":"Sets foreground color to color137","ref":"Bunt.ANSI.html#color137/0"},{"type":"function","title":"Bunt.ANSI.color137_background/0","doc":"Sets background color to color137","ref":"Bunt.ANSI.html#color137_background/0"},{"type":"function","title":"Bunt.ANSI.color138/0","doc":"Sets foreground color to color138","ref":"Bunt.ANSI.html#color138/0"},{"type":"function","title":"Bunt.ANSI.color138_background/0","doc":"Sets background color to color138","ref":"Bunt.ANSI.html#color138_background/0"},{"type":"function","title":"Bunt.ANSI.color139/0","doc":"Sets foreground color to color139","ref":"Bunt.ANSI.html#color139/0"},{"type":"function","title":"Bunt.ANSI.color139_background/0","doc":"Sets background color to color139","ref":"Bunt.ANSI.html#color139_background/0"},{"type":"function","title":"Bunt.ANSI.color140/0","doc":"Sets foreground color to color140","ref":"Bunt.ANSI.html#color140/0"},{"type":"function","title":"Bunt.ANSI.color140_background/0","doc":"Sets background color to color140","ref":"Bunt.ANSI.html#color140_background/0"},{"type":"function","title":"Bunt.ANSI.color141/0","doc":"Sets foreground color to color141","ref":"Bunt.ANSI.html#color141/0"},{"type":"function","title":"Bunt.ANSI.color141_background/0","doc":"Sets background color to color141","ref":"Bunt.ANSI.html#color141_background/0"},{"type":"function","title":"Bunt.ANSI.color142/0","doc":"Sets foreground color to color142","ref":"Bunt.ANSI.html#color142/0"},{"type":"function","title":"Bunt.ANSI.color142_background/0","doc":"Sets background color to color142","ref":"Bunt.ANSI.html#color142_background/0"},{"type":"function","title":"Bunt.ANSI.color143/0","doc":"Sets foreground color to color143","ref":"Bunt.ANSI.html#color143/0"},{"type":"function","title":"Bunt.ANSI.color143_background/0","doc":"Sets background color to color143","ref":"Bunt.ANSI.html#color143_background/0"},{"type":"function","title":"Bunt.ANSI.color144/0","doc":"Sets foreground color to color144","ref":"Bunt.ANSI.html#color144/0"},{"type":"function","title":"Bunt.ANSI.color144_background/0","doc":"Sets background color to color144","ref":"Bunt.ANSI.html#color144_background/0"},{"type":"function","title":"Bunt.ANSI.color145/0","doc":"Sets foreground color to color145","ref":"Bunt.ANSI.html#color145/0"},{"type":"function","title":"Bunt.ANSI.color145_background/0","doc":"Sets background color to color145","ref":"Bunt.ANSI.html#color145_background/0"},{"type":"function","title":"Bunt.ANSI.color146/0","doc":"Sets foreground color to color146","ref":"Bunt.ANSI.html#color146/0"},{"type":"function","title":"Bunt.ANSI.color146_background/0","doc":"Sets background color to color146","ref":"Bunt.ANSI.html#color146_background/0"},{"type":"function","title":"Bunt.ANSI.color147/0","doc":"Sets foreground color to color147","ref":"Bunt.ANSI.html#color147/0"},{"type":"function","title":"Bunt.ANSI.color147_background/0","doc":"Sets background color to color147","ref":"Bunt.ANSI.html#color147_background/0"},{"type":"function","title":"Bunt.ANSI.color148/0","doc":"Sets foreground color to color148","ref":"Bunt.ANSI.html#color148/0"},{"type":"function","title":"Bunt.ANSI.color148_background/0","doc":"Sets background color to color148","ref":"Bunt.ANSI.html#color148_background/0"},{"type":"function","title":"Bunt.ANSI.color149/0","doc":"Sets foreground color to color149","ref":"Bunt.ANSI.html#color149/0"},{"type":"function","title":"Bunt.ANSI.color149_background/0","doc":"Sets background color to color149","ref":"Bunt.ANSI.html#color149_background/0"},{"type":"function","title":"Bunt.ANSI.color150/0","doc":"Sets foreground color to color150","ref":"Bunt.ANSI.html#color150/0"},{"type":"function","title":"Bunt.ANSI.color150_background/0","doc":"Sets background color to color150","ref":"Bunt.ANSI.html#color150_background/0"},{"type":"function","title":"Bunt.ANSI.color151/0","doc":"Sets foreground color to color151","ref":"Bunt.ANSI.html#color151/0"},{"type":"function","title":"Bunt.ANSI.color151_background/0","doc":"Sets background color to color151","ref":"Bunt.ANSI.html#color151_background/0"},{"type":"function","title":"Bunt.ANSI.color152/0","doc":"Sets foreground color to color152","ref":"Bunt.ANSI.html#color152/0"},{"type":"function","title":"Bunt.ANSI.color152_background/0","doc":"Sets background color to color152","ref":"Bunt.ANSI.html#color152_background/0"},{"type":"function","title":"Bunt.ANSI.color153/0","doc":"Sets foreground color to color153","ref":"Bunt.ANSI.html#color153/0"},{"type":"function","title":"Bunt.ANSI.color153_background/0","doc":"Sets background color to color153","ref":"Bunt.ANSI.html#color153_background/0"},{"type":"function","title":"Bunt.ANSI.color154/0","doc":"Sets foreground color to color154","ref":"Bunt.ANSI.html#color154/0"},{"type":"function","title":"Bunt.ANSI.color154_background/0","doc":"Sets background color to color154","ref":"Bunt.ANSI.html#color154_background/0"},{"type":"function","title":"Bunt.ANSI.color155/0","doc":"Sets foreground color to color155","ref":"Bunt.ANSI.html#color155/0"},{"type":"function","title":"Bunt.ANSI.color155_background/0","doc":"Sets background color to color155","ref":"Bunt.ANSI.html#color155_background/0"},{"type":"function","title":"Bunt.ANSI.color156/0","doc":"Sets foreground color to color156","ref":"Bunt.ANSI.html#color156/0"},{"type":"function","title":"Bunt.ANSI.color156_background/0","doc":"Sets background color to color156","ref":"Bunt.ANSI.html#color156_background/0"},{"type":"function","title":"Bunt.ANSI.color157/0","doc":"Sets foreground color to color157","ref":"Bunt.ANSI.html#color157/0"},{"type":"function","title":"Bunt.ANSI.color157_background/0","doc":"Sets background color to color157","ref":"Bunt.ANSI.html#color157_background/0"},{"type":"function","title":"Bunt.ANSI.color158/0","doc":"Sets foreground color to color158","ref":"Bunt.ANSI.html#color158/0"},{"type":"function","title":"Bunt.ANSI.color158_background/0","doc":"Sets background color to color158","ref":"Bunt.ANSI.html#color158_background/0"},{"type":"function","title":"Bunt.ANSI.color159/0","doc":"Sets foreground color to color159","ref":"Bunt.ANSI.html#color159/0"},{"type":"function","title":"Bunt.ANSI.color159_background/0","doc":"Sets background color to color159","ref":"Bunt.ANSI.html#color159_background/0"},{"type":"function","title":"Bunt.ANSI.color160/0","doc":"Sets foreground color to color160","ref":"Bunt.ANSI.html#color160/0"},{"type":"function","title":"Bunt.ANSI.color160_background/0","doc":"Sets background color to color160","ref":"Bunt.ANSI.html#color160_background/0"},{"type":"function","title":"Bunt.ANSI.color161/0","doc":"Sets foreground color to color161","ref":"Bunt.ANSI.html#color161/0"},{"type":"function","title":"Bunt.ANSI.color161_background/0","doc":"Sets background color to color161","ref":"Bunt.ANSI.html#color161_background/0"},{"type":"function","title":"Bunt.ANSI.color162/0","doc":"Sets foreground color to color162","ref":"Bunt.ANSI.html#color162/0"},{"type":"function","title":"Bunt.ANSI.color162_background/0","doc":"Sets background color to color162","ref":"Bunt.ANSI.html#color162_background/0"},{"type":"function","title":"Bunt.ANSI.color163/0","doc":"Sets foreground color to color163","ref":"Bunt.ANSI.html#color163/0"},{"type":"function","title":"Bunt.ANSI.color163_background/0","doc":"Sets background color to color163","ref":"Bunt.ANSI.html#color163_background/0"},{"type":"function","title":"Bunt.ANSI.color164/0","doc":"Sets foreground color to color164","ref":"Bunt.ANSI.html#color164/0"},{"type":"function","title":"Bunt.ANSI.color164_background/0","doc":"Sets background color to color164","ref":"Bunt.ANSI.html#color164_background/0"},{"type":"function","title":"Bunt.ANSI.color165/0","doc":"Sets foreground color to color165","ref":"Bunt.ANSI.html#color165/0"},{"type":"function","title":"Bunt.ANSI.color165_background/0","doc":"Sets background color to color165","ref":"Bunt.ANSI.html#color165_background/0"},{"type":"function","title":"Bunt.ANSI.color166/0","doc":"Sets foreground color to color166","ref":"Bunt.ANSI.html#color166/0"},{"type":"function","title":"Bunt.ANSI.color166_background/0","doc":"Sets background color to color166","ref":"Bunt.ANSI.html#color166_background/0"},{"type":"function","title":"Bunt.ANSI.color167/0","doc":"Sets foreground color to color167","ref":"Bunt.ANSI.html#color167/0"},{"type":"function","title":"Bunt.ANSI.color167_background/0","doc":"Sets background color to color167","ref":"Bunt.ANSI.html#color167_background/0"},{"type":"function","title":"Bunt.ANSI.color168/0","doc":"Sets foreground color to color168","ref":"Bunt.ANSI.html#color168/0"},{"type":"function","title":"Bunt.ANSI.color168_background/0","doc":"Sets background color to color168","ref":"Bunt.ANSI.html#color168_background/0"},{"type":"function","title":"Bunt.ANSI.color169/0","doc":"Sets foreground color to color169","ref":"Bunt.ANSI.html#color169/0"},{"type":"function","title":"Bunt.ANSI.color169_background/0","doc":"Sets background color to color169","ref":"Bunt.ANSI.html#color169_background/0"},{"type":"function","title":"Bunt.ANSI.color170/0","doc":"Sets foreground color to color170","ref":"Bunt.ANSI.html#color170/0"},{"type":"function","title":"Bunt.ANSI.color170_background/0","doc":"Sets background color to color170","ref":"Bunt.ANSI.html#color170_background/0"},{"type":"function","title":"Bunt.ANSI.color171/0","doc":"Sets foreground color to color171","ref":"Bunt.ANSI.html#color171/0"},{"type":"function","title":"Bunt.ANSI.color171_background/0","doc":"Sets background color to color171","ref":"Bunt.ANSI.html#color171_background/0"},{"type":"function","title":"Bunt.ANSI.color172/0","doc":"Sets foreground color to color172","ref":"Bunt.ANSI.html#color172/0"},{"type":"function","title":"Bunt.ANSI.color172_background/0","doc":"Sets background color to color172","ref":"Bunt.ANSI.html#color172_background/0"},{"type":"function","title":"Bunt.ANSI.color173/0","doc":"Sets foreground color to color173","ref":"Bunt.ANSI.html#color173/0"},{"type":"function","title":"Bunt.ANSI.color173_background/0","doc":"Sets background color to color173","ref":"Bunt.ANSI.html#color173_background/0"},{"type":"function","title":"Bunt.ANSI.color174/0","doc":"Sets foreground color to color174","ref":"Bunt.ANSI.html#color174/0"},{"type":"function","title":"Bunt.ANSI.color174_background/0","doc":"Sets background color to color174","ref":"Bunt.ANSI.html#color174_background/0"},{"type":"function","title":"Bunt.ANSI.color175/0","doc":"Sets foreground color to color175","ref":"Bunt.ANSI.html#color175/0"},{"type":"function","title":"Bunt.ANSI.color175_background/0","doc":"Sets background color to color175","ref":"Bunt.ANSI.html#color175_background/0"},{"type":"function","title":"Bunt.ANSI.color176/0","doc":"Sets foreground color to color176","ref":"Bunt.ANSI.html#color176/0"},{"type":"function","title":"Bunt.ANSI.color176_background/0","doc":"Sets background color to color176","ref":"Bunt.ANSI.html#color176_background/0"},{"type":"function","title":"Bunt.ANSI.color177/0","doc":"Sets foreground color to color177","ref":"Bunt.ANSI.html#color177/0"},{"type":"function","title":"Bunt.ANSI.color177_background/0","doc":"Sets background color to color177","ref":"Bunt.ANSI.html#color177_background/0"},{"type":"function","title":"Bunt.ANSI.color178/0","doc":"Sets foreground color to color178","ref":"Bunt.ANSI.html#color178/0"},{"type":"function","title":"Bunt.ANSI.color178_background/0","doc":"Sets background color to color178","ref":"Bunt.ANSI.html#color178_background/0"},{"type":"function","title":"Bunt.ANSI.color179/0","doc":"Sets foreground color to color179","ref":"Bunt.ANSI.html#color179/0"},{"type":"function","title":"Bunt.ANSI.color179_background/0","doc":"Sets background color to color179","ref":"Bunt.ANSI.html#color179_background/0"},{"type":"function","title":"Bunt.ANSI.color180/0","doc":"Sets foreground color to color180","ref":"Bunt.ANSI.html#color180/0"},{"type":"function","title":"Bunt.ANSI.color180_background/0","doc":"Sets background color to color180","ref":"Bunt.ANSI.html#color180_background/0"},{"type":"function","title":"Bunt.ANSI.color181/0","doc":"Sets foreground color to color181","ref":"Bunt.ANSI.html#color181/0"},{"type":"function","title":"Bunt.ANSI.color181_background/0","doc":"Sets background color to color181","ref":"Bunt.ANSI.html#color181_background/0"},{"type":"function","title":"Bunt.ANSI.color182/0","doc":"Sets foreground color to color182","ref":"Bunt.ANSI.html#color182/0"},{"type":"function","title":"Bunt.ANSI.color182_background/0","doc":"Sets background color to color182","ref":"Bunt.ANSI.html#color182_background/0"},{"type":"function","title":"Bunt.ANSI.color183/0","doc":"Sets foreground color to color183","ref":"Bunt.ANSI.html#color183/0"},{"type":"function","title":"Bunt.ANSI.color183_background/0","doc":"Sets background color to color183","ref":"Bunt.ANSI.html#color183_background/0"},{"type":"function","title":"Bunt.ANSI.color184/0","doc":"Sets foreground color to color184","ref":"Bunt.ANSI.html#color184/0"},{"type":"function","title":"Bunt.ANSI.color184_background/0","doc":"Sets background color to color184","ref":"Bunt.ANSI.html#color184_background/0"},{"type":"function","title":"Bunt.ANSI.color185/0","doc":"Sets foreground color to color185","ref":"Bunt.ANSI.html#color185/0"},{"type":"function","title":"Bunt.ANSI.color185_background/0","doc":"Sets background color to color185","ref":"Bunt.ANSI.html#color185_background/0"},{"type":"function","title":"Bunt.ANSI.color186/0","doc":"Sets foreground color to color186","ref":"Bunt.ANSI.html#color186/0"},{"type":"function","title":"Bunt.ANSI.color186_background/0","doc":"Sets background color to color186","ref":"Bunt.ANSI.html#color186_background/0"},{"type":"function","title":"Bunt.ANSI.color187/0","doc":"Sets foreground color to color187","ref":"Bunt.ANSI.html#color187/0"},{"type":"function","title":"Bunt.ANSI.color187_background/0","doc":"Sets background color to color187","ref":"Bunt.ANSI.html#color187_background/0"},{"type":"function","title":"Bunt.ANSI.color188/0","doc":"Sets foreground color to color188","ref":"Bunt.ANSI.html#color188/0"},{"type":"function","title":"Bunt.ANSI.color188_background/0","doc":"Sets background color to color188","ref":"Bunt.ANSI.html#color188_background/0"},{"type":"function","title":"Bunt.ANSI.color189/0","doc":"Sets foreground color to color189","ref":"Bunt.ANSI.html#color189/0"},{"type":"function","title":"Bunt.ANSI.color189_background/0","doc":"Sets background color to color189","ref":"Bunt.ANSI.html#color189_background/0"},{"type":"function","title":"Bunt.ANSI.color190/0","doc":"Sets foreground color to color190","ref":"Bunt.ANSI.html#color190/0"},{"type":"function","title":"Bunt.ANSI.color190_background/0","doc":"Sets background color to color190","ref":"Bunt.ANSI.html#color190_background/0"},{"type":"function","title":"Bunt.ANSI.color191/0","doc":"Sets foreground color to color191","ref":"Bunt.ANSI.html#color191/0"},{"type":"function","title":"Bunt.ANSI.color191_background/0","doc":"Sets background color to color191","ref":"Bunt.ANSI.html#color191_background/0"},{"type":"function","title":"Bunt.ANSI.color192/0","doc":"Sets foreground color to color192","ref":"Bunt.ANSI.html#color192/0"},{"type":"function","title":"Bunt.ANSI.color192_background/0","doc":"Sets background color to color192","ref":"Bunt.ANSI.html#color192_background/0"},{"type":"function","title":"Bunt.ANSI.color193/0","doc":"Sets foreground color to color193","ref":"Bunt.ANSI.html#color193/0"},{"type":"function","title":"Bunt.ANSI.color193_background/0","doc":"Sets background color to color193","ref":"Bunt.ANSI.html#color193_background/0"},{"type":"function","title":"Bunt.ANSI.color194/0","doc":"Sets foreground color to color194","ref":"Bunt.ANSI.html#color194/0"},{"type":"function","title":"Bunt.ANSI.color194_background/0","doc":"Sets background color to color194","ref":"Bunt.ANSI.html#color194_background/0"},{"type":"function","title":"Bunt.ANSI.color195/0","doc":"Sets foreground color to color195","ref":"Bunt.ANSI.html#color195/0"},{"type":"function","title":"Bunt.ANSI.color195_background/0","doc":"Sets background color to color195","ref":"Bunt.ANSI.html#color195_background/0"},{"type":"function","title":"Bunt.ANSI.color196/0","doc":"Sets foreground color to color196","ref":"Bunt.ANSI.html#color196/0"},{"type":"function","title":"Bunt.ANSI.color196_background/0","doc":"Sets background color to color196","ref":"Bunt.ANSI.html#color196_background/0"},{"type":"function","title":"Bunt.ANSI.color197/0","doc":"Sets foreground color to color197","ref":"Bunt.ANSI.html#color197/0"},{"type":"function","title":"Bunt.ANSI.color197_background/0","doc":"Sets background color to color197","ref":"Bunt.ANSI.html#color197_background/0"},{"type":"function","title":"Bunt.ANSI.color198/0","doc":"Sets foreground color to color198","ref":"Bunt.ANSI.html#color198/0"},{"type":"function","title":"Bunt.ANSI.color198_background/0","doc":"Sets background color to color198","ref":"Bunt.ANSI.html#color198_background/0"},{"type":"function","title":"Bunt.ANSI.color199/0","doc":"Sets foreground color to color199","ref":"Bunt.ANSI.html#color199/0"},{"type":"function","title":"Bunt.ANSI.color199_background/0","doc":"Sets background color to color199","ref":"Bunt.ANSI.html#color199_background/0"},{"type":"function","title":"Bunt.ANSI.color200/0","doc":"Sets foreground color to color200","ref":"Bunt.ANSI.html#color200/0"},{"type":"function","title":"Bunt.ANSI.color200_background/0","doc":"Sets background color to color200","ref":"Bunt.ANSI.html#color200_background/0"},{"type":"function","title":"Bunt.ANSI.color201/0","doc":"Sets foreground color to color201","ref":"Bunt.ANSI.html#color201/0"},{"type":"function","title":"Bunt.ANSI.color201_background/0","doc":"Sets background color to color201","ref":"Bunt.ANSI.html#color201_background/0"},{"type":"function","title":"Bunt.ANSI.color202/0","doc":"Sets foreground color to color202","ref":"Bunt.ANSI.html#color202/0"},{"type":"function","title":"Bunt.ANSI.color202_background/0","doc":"Sets background color to color202","ref":"Bunt.ANSI.html#color202_background/0"},{"type":"function","title":"Bunt.ANSI.color203/0","doc":"Sets foreground color to color203","ref":"Bunt.ANSI.html#color203/0"},{"type":"function","title":"Bunt.ANSI.color203_background/0","doc":"Sets background color to color203","ref":"Bunt.ANSI.html#color203_background/0"},{"type":"function","title":"Bunt.ANSI.color204/0","doc":"Sets foreground color to color204","ref":"Bunt.ANSI.html#color204/0"},{"type":"function","title":"Bunt.ANSI.color204_background/0","doc":"Sets background color to color204","ref":"Bunt.ANSI.html#color204_background/0"},{"type":"function","title":"Bunt.ANSI.color205/0","doc":"Sets foreground color to color205","ref":"Bunt.ANSI.html#color205/0"},{"type":"function","title":"Bunt.ANSI.color205_background/0","doc":"Sets background color to color205","ref":"Bunt.ANSI.html#color205_background/0"},{"type":"function","title":"Bunt.ANSI.color206/0","doc":"Sets foreground color to color206","ref":"Bunt.ANSI.html#color206/0"},{"type":"function","title":"Bunt.ANSI.color206_background/0","doc":"Sets background color to color206","ref":"Bunt.ANSI.html#color206_background/0"},{"type":"function","title":"Bunt.ANSI.color207/0","doc":"Sets foreground color to color207","ref":"Bunt.ANSI.html#color207/0"},{"type":"function","title":"Bunt.ANSI.color207_background/0","doc":"Sets background color to color207","ref":"Bunt.ANSI.html#color207_background/0"},{"type":"function","title":"Bunt.ANSI.color208/0","doc":"Sets foreground color to color208","ref":"Bunt.ANSI.html#color208/0"},{"type":"function","title":"Bunt.ANSI.color208_background/0","doc":"Sets background color to color208","ref":"Bunt.ANSI.html#color208_background/0"},{"type":"function","title":"Bunt.ANSI.color209/0","doc":"Sets foreground color to color209","ref":"Bunt.ANSI.html#color209/0"},{"type":"function","title":"Bunt.ANSI.color209_background/0","doc":"Sets background color to color209","ref":"Bunt.ANSI.html#color209_background/0"},{"type":"function","title":"Bunt.ANSI.color210/0","doc":"Sets foreground color to color210","ref":"Bunt.ANSI.html#color210/0"},{"type":"function","title":"Bunt.ANSI.color210_background/0","doc":"Sets background color to color210","ref":"Bunt.ANSI.html#color210_background/0"},{"type":"function","title":"Bunt.ANSI.color211/0","doc":"Sets foreground color to color211","ref":"Bunt.ANSI.html#color211/0"},{"type":"function","title":"Bunt.ANSI.color211_background/0","doc":"Sets background color to color211","ref":"Bunt.ANSI.html#color211_background/0"},{"type":"function","title":"Bunt.ANSI.color212/0","doc":"Sets foreground color to color212","ref":"Bunt.ANSI.html#color212/0"},{"type":"function","title":"Bunt.ANSI.color212_background/0","doc":"Sets background color to color212","ref":"Bunt.ANSI.html#color212_background/0"},{"type":"function","title":"Bunt.ANSI.color213/0","doc":"Sets foreground color to color213","ref":"Bunt.ANSI.html#color213/0"},{"type":"function","title":"Bunt.ANSI.color213_background/0","doc":"Sets background color to color213","ref":"Bunt.ANSI.html#color213_background/0"},{"type":"function","title":"Bunt.ANSI.color214/0","doc":"Sets foreground color to color214","ref":"Bunt.ANSI.html#color214/0"},{"type":"function","title":"Bunt.ANSI.color214_background/0","doc":"Sets background color to color214","ref":"Bunt.ANSI.html#color214_background/0"},{"type":"function","title":"Bunt.ANSI.color215/0","doc":"Sets foreground color to color215","ref":"Bunt.ANSI.html#color215/0"},{"type":"function","title":"Bunt.ANSI.color215_background/0","doc":"Sets background color to color215","ref":"Bunt.ANSI.html#color215_background/0"},{"type":"function","title":"Bunt.ANSI.color216/0","doc":"Sets foreground color to color216","ref":"Bunt.ANSI.html#color216/0"},{"type":"function","title":"Bunt.ANSI.color216_background/0","doc":"Sets background color to color216","ref":"Bunt.ANSI.html#color216_background/0"},{"type":"function","title":"Bunt.ANSI.color217/0","doc":"Sets foreground color to color217","ref":"Bunt.ANSI.html#color217/0"},{"type":"function","title":"Bunt.ANSI.color217_background/0","doc":"Sets background color to color217","ref":"Bunt.ANSI.html#color217_background/0"},{"type":"function","title":"Bunt.ANSI.color218/0","doc":"Sets foreground color to color218","ref":"Bunt.ANSI.html#color218/0"},{"type":"function","title":"Bunt.ANSI.color218_background/0","doc":"Sets background color to color218","ref":"Bunt.ANSI.html#color218_background/0"},{"type":"function","title":"Bunt.ANSI.color219/0","doc":"Sets foreground color to color219","ref":"Bunt.ANSI.html#color219/0"},{"type":"function","title":"Bunt.ANSI.color219_background/0","doc":"Sets background color to color219","ref":"Bunt.ANSI.html#color219_background/0"},{"type":"function","title":"Bunt.ANSI.color220/0","doc":"Sets foreground color to color220","ref":"Bunt.ANSI.html#color220/0"},{"type":"function","title":"Bunt.ANSI.color220_background/0","doc":"Sets background color to color220","ref":"Bunt.ANSI.html#color220_background/0"},{"type":"function","title":"Bunt.ANSI.color221/0","doc":"Sets foreground color to color221","ref":"Bunt.ANSI.html#color221/0"},{"type":"function","title":"Bunt.ANSI.color221_background/0","doc":"Sets background color to color221","ref":"Bunt.ANSI.html#color221_background/0"},{"type":"function","title":"Bunt.ANSI.color222/0","doc":"Sets foreground color to color222","ref":"Bunt.ANSI.html#color222/0"},{"type":"function","title":"Bunt.ANSI.color222_background/0","doc":"Sets background color to color222","ref":"Bunt.ANSI.html#color222_background/0"},{"type":"function","title":"Bunt.ANSI.color223/0","doc":"Sets foreground color to color223","ref":"Bunt.ANSI.html#color223/0"},{"type":"function","title":"Bunt.ANSI.color223_background/0","doc":"Sets background color to color223","ref":"Bunt.ANSI.html#color223_background/0"},{"type":"function","title":"Bunt.ANSI.color224/0","doc":"Sets foreground color to color224","ref":"Bunt.ANSI.html#color224/0"},{"type":"function","title":"Bunt.ANSI.color224_background/0","doc":"Sets background color to color224","ref":"Bunt.ANSI.html#color224_background/0"},{"type":"function","title":"Bunt.ANSI.color225/0","doc":"Sets foreground color to color225","ref":"Bunt.ANSI.html#color225/0"},{"type":"function","title":"Bunt.ANSI.color225_background/0","doc":"Sets background color to color225","ref":"Bunt.ANSI.html#color225_background/0"},{"type":"function","title":"Bunt.ANSI.color226/0","doc":"Sets foreground color to color226","ref":"Bunt.ANSI.html#color226/0"},{"type":"function","title":"Bunt.ANSI.color226_background/0","doc":"Sets background color to color226","ref":"Bunt.ANSI.html#color226_background/0"},{"type":"function","title":"Bunt.ANSI.color227/0","doc":"Sets foreground color to color227","ref":"Bunt.ANSI.html#color227/0"},{"type":"function","title":"Bunt.ANSI.color227_background/0","doc":"Sets background color to color227","ref":"Bunt.ANSI.html#color227_background/0"},{"type":"function","title":"Bunt.ANSI.color228/0","doc":"Sets foreground color to color228","ref":"Bunt.ANSI.html#color228/0"},{"type":"function","title":"Bunt.ANSI.color228_background/0","doc":"Sets background color to color228","ref":"Bunt.ANSI.html#color228_background/0"},{"type":"function","title":"Bunt.ANSI.color229/0","doc":"Sets foreground color to color229","ref":"Bunt.ANSI.html#color229/0"},{"type":"function","title":"Bunt.ANSI.color229_background/0","doc":"Sets background color to color229","ref":"Bunt.ANSI.html#color229_background/0"},{"type":"function","title":"Bunt.ANSI.color230/0","doc":"Sets foreground color to color230","ref":"Bunt.ANSI.html#color230/0"},{"type":"function","title":"Bunt.ANSI.color230_background/0","doc":"Sets background color to color230","ref":"Bunt.ANSI.html#color230_background/0"},{"type":"function","title":"Bunt.ANSI.color231/0","doc":"Sets foreground color to color231","ref":"Bunt.ANSI.html#color231/0"},{"type":"function","title":"Bunt.ANSI.color231_background/0","doc":"Sets background color to color231","ref":"Bunt.ANSI.html#color231_background/0"},{"type":"function","title":"Bunt.ANSI.color232/0","doc":"Sets foreground color to color232","ref":"Bunt.ANSI.html#color232/0"},{"type":"function","title":"Bunt.ANSI.color232_background/0","doc":"Sets background color to color232","ref":"Bunt.ANSI.html#color232_background/0"},{"type":"function","title":"Bunt.ANSI.color233/0","doc":"Sets foreground color to color233","ref":"Bunt.ANSI.html#color233/0"},{"type":"function","title":"Bunt.ANSI.color233_background/0","doc":"Sets background color to color233","ref":"Bunt.ANSI.html#color233_background/0"},{"type":"function","title":"Bunt.ANSI.color234/0","doc":"Sets foreground color to color234","ref":"Bunt.ANSI.html#color234/0"},{"type":"function","title":"Bunt.ANSI.color234_background/0","doc":"Sets background color to color234","ref":"Bunt.ANSI.html#color234_background/0"},{"type":"function","title":"Bunt.ANSI.color235/0","doc":"Sets foreground color to color235","ref":"Bunt.ANSI.html#color235/0"},{"type":"function","title":"Bunt.ANSI.color235_background/0","doc":"Sets background color to color235","ref":"Bunt.ANSI.html#color235_background/0"},{"type":"function","title":"Bunt.ANSI.color236/0","doc":"Sets foreground color to color236","ref":"Bunt.ANSI.html#color236/0"},{"type":"function","title":"Bunt.ANSI.color236_background/0","doc":"Sets background color to color236","ref":"Bunt.ANSI.html#color236_background/0"},{"type":"function","title":"Bunt.ANSI.color237/0","doc":"Sets foreground color to color237","ref":"Bunt.ANSI.html#color237/0"},{"type":"function","title":"Bunt.ANSI.color237_background/0","doc":"Sets background color to color237","ref":"Bunt.ANSI.html#color237_background/0"},{"type":"function","title":"Bunt.ANSI.color238/0","doc":"Sets foreground color to color238","ref":"Bunt.ANSI.html#color238/0"},{"type":"function","title":"Bunt.ANSI.color238_background/0","doc":"Sets background color to color238","ref":"Bunt.ANSI.html#color238_background/0"},{"type":"function","title":"Bunt.ANSI.color239/0","doc":"Sets foreground color to color239","ref":"Bunt.ANSI.html#color239/0"},{"type":"function","title":"Bunt.ANSI.color239_background/0","doc":"Sets background color to color239","ref":"Bunt.ANSI.html#color239_background/0"},{"type":"function","title":"Bunt.ANSI.color240/0","doc":"Sets foreground color to color240","ref":"Bunt.ANSI.html#color240/0"},{"type":"function","title":"Bunt.ANSI.color240_background/0","doc":"Sets background color to color240","ref":"Bunt.ANSI.html#color240_background/0"},{"type":"function","title":"Bunt.ANSI.color241/0","doc":"Sets foreground color to color241","ref":"Bunt.ANSI.html#color241/0"},{"type":"function","title":"Bunt.ANSI.color241_background/0","doc":"Sets background color to color241","ref":"Bunt.ANSI.html#color241_background/0"},{"type":"function","title":"Bunt.ANSI.color242/0","doc":"Sets foreground color to color242","ref":"Bunt.ANSI.html#color242/0"},{"type":"function","title":"Bunt.ANSI.color242_background/0","doc":"Sets background color to color242","ref":"Bunt.ANSI.html#color242_background/0"},{"type":"function","title":"Bunt.ANSI.color243/0","doc":"Sets foreground color to color243","ref":"Bunt.ANSI.html#color243/0"},{"type":"function","title":"Bunt.ANSI.color243_background/0","doc":"Sets background color to color243","ref":"Bunt.ANSI.html#color243_background/0"},{"type":"function","title":"Bunt.ANSI.color244/0","doc":"Sets foreground color to color244","ref":"Bunt.ANSI.html#color244/0"},{"type":"function","title":"Bunt.ANSI.color244_background/0","doc":"Sets background color to color244","ref":"Bunt.ANSI.html#color244_background/0"},{"type":"function","title":"Bunt.ANSI.color245/0","doc":"Sets foreground color to color245","ref":"Bunt.ANSI.html#color245/0"},{"type":"function","title":"Bunt.ANSI.color245_background/0","doc":"Sets background color to color245","ref":"Bunt.ANSI.html#color245_background/0"},{"type":"function","title":"Bunt.ANSI.color246/0","doc":"Sets foreground color to color246","ref":"Bunt.ANSI.html#color246/0"},{"type":"function","title":"Bunt.ANSI.color246_background/0","doc":"Sets background color to color246","ref":"Bunt.ANSI.html#color246_background/0"},{"type":"function","title":"Bunt.ANSI.color247/0","doc":"Sets foreground color to color247","ref":"Bunt.ANSI.html#color247/0"},{"type":"function","title":"Bunt.ANSI.color247_background/0","doc":"Sets background color to color247","ref":"Bunt.ANSI.html#color247_background/0"},{"type":"function","title":"Bunt.ANSI.color248/0","doc":"Sets foreground color to color248","ref":"Bunt.ANSI.html#color248/0"},{"type":"function","title":"Bunt.ANSI.color248_background/0","doc":"Sets background color to color248","ref":"Bunt.ANSI.html#color248_background/0"},{"type":"function","title":"Bunt.ANSI.color249/0","doc":"Sets foreground color to color249","ref":"Bunt.ANSI.html#color249/0"},{"type":"function","title":"Bunt.ANSI.color249_background/0","doc":"Sets background color to color249","ref":"Bunt.ANSI.html#color249_background/0"},{"type":"function","title":"Bunt.ANSI.color250/0","doc":"Sets foreground color to color250","ref":"Bunt.ANSI.html#color250/0"},{"type":"function","title":"Bunt.ANSI.color250_background/0","doc":"Sets background color to color250","ref":"Bunt.ANSI.html#color250_background/0"},{"type":"function","title":"Bunt.ANSI.color251/0","doc":"Sets foreground color to color251","ref":"Bunt.ANSI.html#color251/0"},{"type":"function","title":"Bunt.ANSI.color251_background/0","doc":"Sets background color to color251","ref":"Bunt.ANSI.html#color251_background/0"},{"type":"function","title":"Bunt.ANSI.color252/0","doc":"Sets foreground color to color252","ref":"Bunt.ANSI.html#color252/0"},{"type":"function","title":"Bunt.ANSI.color252_background/0","doc":"Sets background color to color252","ref":"Bunt.ANSI.html#color252_background/0"},{"type":"function","title":"Bunt.ANSI.color253/0","doc":"Sets foreground color to color253","ref":"Bunt.ANSI.html#color253/0"},{"type":"function","title":"Bunt.ANSI.color253_background/0","doc":"Sets background color to color253","ref":"Bunt.ANSI.html#color253_background/0"},{"type":"function","title":"Bunt.ANSI.color254/0","doc":"Sets foreground color to color254","ref":"Bunt.ANSI.html#color254/0"},{"type":"function","title":"Bunt.ANSI.color254_background/0","doc":"Sets background color to color254","ref":"Bunt.ANSI.html#color254_background/0"},{"type":"function","title":"Bunt.ANSI.color255/0","doc":"Sets foreground color to color255","ref":"Bunt.ANSI.html#color255/0"},{"type":"function","title":"Bunt.ANSI.color255_background/0","doc":"Sets background color to color255","ref":"Bunt.ANSI.html#color255_background/0"},{"type":"function","title":"Bunt.ANSI.color_aliases/0","doc":"","ref":"Bunt.ANSI.html#color_aliases/0"},{"type":"function","title":"Bunt.ANSI.color_tuples/0","doc":"","ref":"Bunt.ANSI.html#color_tuples/0"},{"type":"function","title":"Bunt.ANSI.conceal/0","doc":"Conceal. Not widely supported","ref":"Bunt.ANSI.html#conceal/0"},{"type":"function","title":"Bunt.ANSI.coral/0","doc":"Sets foreground color to coral","ref":"Bunt.ANSI.html#coral/0"},{"type":"function","title":"Bunt.ANSI.coral_background/0","doc":"Sets background color to coral","ref":"Bunt.ANSI.html#coral_background/0"},{"type":"function","title":"Bunt.ANSI.crossed_out/0","doc":"Crossed-out. Characters legible, but marked for deletion. Not widely supported","ref":"Bunt.ANSI.html#crossed_out/0"},{"type":"function","title":"Bunt.ANSI.cyan/0","doc":"Sets foreground color to cyan","ref":"Bunt.ANSI.html#cyan/0"},{"type":"function","title":"Bunt.ANSI.cyan_background/0","doc":"Sets background color to cyan","ref":"Bunt.ANSI.html#cyan_background/0"},{"type":"function","title":"Bunt.ANSI.darkblue/0","doc":"Sets foreground color to darkblue","ref":"Bunt.ANSI.html#darkblue/0"},{"type":"function","title":"Bunt.ANSI.darkblue_background/0","doc":"Sets background color to darkblue","ref":"Bunt.ANSI.html#darkblue_background/0"},{"type":"function","title":"Bunt.ANSI.darkcyan/0","doc":"Sets foreground color to darkcyan","ref":"Bunt.ANSI.html#darkcyan/0"},{"type":"function","title":"Bunt.ANSI.darkcyan_background/0","doc":"Sets background color to darkcyan","ref":"Bunt.ANSI.html#darkcyan_background/0"},{"type":"function","title":"Bunt.ANSI.darkgreen/0","doc":"Sets foreground color to darkgreen","ref":"Bunt.ANSI.html#darkgreen/0"},{"type":"function","title":"Bunt.ANSI.darkgreen_background/0","doc":"Sets background color to darkgreen","ref":"Bunt.ANSI.html#darkgreen_background/0"},{"type":"function","title":"Bunt.ANSI.darkmagenta/0","doc":"Sets foreground color to darkmagenta","ref":"Bunt.ANSI.html#darkmagenta/0"},{"type":"function","title":"Bunt.ANSI.darkmagenta_background/0","doc":"Sets background color to darkmagenta","ref":"Bunt.ANSI.html#darkmagenta_background/0"},{"type":"function","title":"Bunt.ANSI.darkorange/0","doc":"Sets foreground color to darkorange","ref":"Bunt.ANSI.html#darkorange/0"},{"type":"function","title":"Bunt.ANSI.darkorange_background/0","doc":"Sets background color to darkorange","ref":"Bunt.ANSI.html#darkorange_background/0"},{"type":"function","title":"Bunt.ANSI.darkred/0","doc":"Sets foreground color to darkred","ref":"Bunt.ANSI.html#darkred/0"},{"type":"function","title":"Bunt.ANSI.darkred_background/0","doc":"Sets background color to darkred","ref":"Bunt.ANSI.html#darkred_background/0"},{"type":"function","title":"Bunt.ANSI.darkslategray/0","doc":"Sets foreground color to darkslategray","ref":"Bunt.ANSI.html#darkslategray/0"},{"type":"function","title":"Bunt.ANSI.darkslategray_background/0","doc":"Sets background color to darkslategray","ref":"Bunt.ANSI.html#darkslategray_background/0"},{"type":"function","title":"Bunt.ANSI.deepskyblue/0","doc":"Sets foreground color to deepskyblue","ref":"Bunt.ANSI.html#deepskyblue/0"},{"type":"function","title":"Bunt.ANSI.deepskyblue_background/0","doc":"Sets background color to deepskyblue","ref":"Bunt.ANSI.html#deepskyblue_background/0"},{"type":"function","title":"Bunt.ANSI.default_background/0","doc":"Default background color","ref":"Bunt.ANSI.html#default_background/0"},{"type":"function","title":"Bunt.ANSI.default_color/0","doc":"Default text color","ref":"Bunt.ANSI.html#default_color/0"},{"type":"function","title":"Bunt.ANSI.dimgray/0","doc":"Sets foreground color to dimgray","ref":"Bunt.ANSI.html#dimgray/0"},{"type":"function","title":"Bunt.ANSI.dimgray_background/0","doc":"Sets background color to dimgray","ref":"Bunt.ANSI.html#dimgray_background/0"},{"type":"function","title":"Bunt.ANSI.enabled?/0","doc":"Checks if ANSI coloring is supported and enabled on this machine.\n\nThis function simply reads the configuration value for\n`:ansi_enabled` in the `:elixir` application. The value is by\ndefault `false` unless Elixir can detect during startup that\nboth `stdout` and `stderr` are terminals.","ref":"Bunt.ANSI.html#enabled?/0"},{"type":"function","title":"Bunt.ANSI.encircled/0","doc":"Encircled","ref":"Bunt.ANSI.html#encircled/0"},{"type":"function","title":"Bunt.ANSI.faint/0","doc":"Faint (decreased intensity), not widely supported","ref":"Bunt.ANSI.html#faint/0"},{"type":"function","title":"Bunt.ANSI.font_1/0","doc":"Sets alternative font 1","ref":"Bunt.ANSI.html#font_1/0"},{"type":"function","title":"Bunt.ANSI.font_2/0","doc":"Sets alternative font 2","ref":"Bunt.ANSI.html#font_2/0"},{"type":"function","title":"Bunt.ANSI.font_3/0","doc":"Sets alternative font 3","ref":"Bunt.ANSI.html#font_3/0"},{"type":"function","title":"Bunt.ANSI.font_4/0","doc":"Sets alternative font 4","ref":"Bunt.ANSI.html#font_4/0"},{"type":"function","title":"Bunt.ANSI.font_5/0","doc":"Sets alternative font 5","ref":"Bunt.ANSI.html#font_5/0"},{"type":"function","title":"Bunt.ANSI.font_6/0","doc":"Sets alternative font 6","ref":"Bunt.ANSI.html#font_6/0"},{"type":"function","title":"Bunt.ANSI.font_7/0","doc":"Sets alternative font 7","ref":"Bunt.ANSI.html#font_7/0"},{"type":"function","title":"Bunt.ANSI.font_8/0","doc":"Sets alternative font 8","ref":"Bunt.ANSI.html#font_8/0"},{"type":"function","title":"Bunt.ANSI.font_9/0","doc":"Sets alternative font 9","ref":"Bunt.ANSI.html#font_9/0"},{"type":"function","title":"Bunt.ANSI.format/2","doc":"Formats a chardata-like argument by converting named ANSI sequences into actual\nANSI codes.\n\nThe named sequences are represented by atoms.\n\nIt will also append an `IO.ANSI.reset/0` to the chardata when a conversion is\nperformed. If you don't want this behaviour, use `format_fragment/2`.\n\nAn optional boolean parameter can be passed to enable or disable\nemitting actual ANSI codes. When `false`, no ANSI codes will emitted.\nBy default checks if ANSI is enabled using the `enabled?/0` function.","ref":"Bunt.ANSI.html#format/2"},{"type":"function","title":"Examples - Bunt.ANSI.format/2","doc":"iex> IO.ANSI.format([\"Hello, \", :red, :bright, \"world!\"], true)\n    [[[[[[], \"Hello, \"] | \"\\e[31m\"] | \"\\e[1m\"], \"world!\"] | \"\\e[0m\"]","ref":"Bunt.ANSI.html#format/2-examples"},{"type":"function","title":"Bunt.ANSI.format_fragment/2","doc":"Formats a chardata-like argument by converting named ANSI sequences into actual\nANSI codes.\n\nThe named sequences are represented by atoms.\n\nAn optional boolean parameter can be passed to enable or disable\nemitting actual ANSI codes. When `false`, no ANSI codes will emitted.\nBy default checks if ANSI is enabled using the `enabled?/0` function.","ref":"Bunt.ANSI.html#format_fragment/2"},{"type":"function","title":"Examples - Bunt.ANSI.format_fragment/2","doc":"iex> IO.ANSI.format_fragment([:bright, 'Word'], true)\n    [[[[[[] | \"\\e[1m\"], 87], 111], 114], 100]","ref":"Bunt.ANSI.html#format_fragment/2-examples"},{"type":"function","title":"Bunt.ANSI.framed/0","doc":"Framed","ref":"Bunt.ANSI.html#framed/0"},{"type":"function","title":"Bunt.ANSI.fuchsia/0","doc":"Sets foreground color to fuchsia","ref":"Bunt.ANSI.html#fuchsia/0"},{"type":"function","title":"Bunt.ANSI.fuchsia_background/0","doc":"Sets background color to fuchsia","ref":"Bunt.ANSI.html#fuchsia_background/0"},{"type":"function","title":"Bunt.ANSI.gold/0","doc":"Sets foreground color to gold","ref":"Bunt.ANSI.html#gold/0"},{"type":"function","title":"Bunt.ANSI.gold_background/0","doc":"Sets background color to gold","ref":"Bunt.ANSI.html#gold_background/0"},{"type":"function","title":"Bunt.ANSI.goldenrod/0","doc":"Sets foreground color to goldenrod","ref":"Bunt.ANSI.html#goldenrod/0"},{"type":"function","title":"Bunt.ANSI.goldenrod_background/0","doc":"Sets background color to goldenrod","ref":"Bunt.ANSI.html#goldenrod_background/0"},{"type":"function","title":"Bunt.ANSI.green/0","doc":"Sets foreground color to green","ref":"Bunt.ANSI.html#green/0"},{"type":"function","title":"Bunt.ANSI.green_background/0","doc":"Sets background color to green","ref":"Bunt.ANSI.html#green_background/0"},{"type":"function","title":"Bunt.ANSI.greenyellow/0","doc":"Sets foreground color to greenyellow","ref":"Bunt.ANSI.html#greenyellow/0"},{"type":"function","title":"Bunt.ANSI.greenyellow_background/0","doc":"Sets background color to greenyellow","ref":"Bunt.ANSI.html#greenyellow_background/0"},{"type":"function","title":"Bunt.ANSI.home/0","doc":"Sends cursor home","ref":"Bunt.ANSI.html#home/0"},{"type":"function","title":"Bunt.ANSI.hotpink/0","doc":"Sets foreground color to hotpink","ref":"Bunt.ANSI.html#hotpink/0"},{"type":"function","title":"Bunt.ANSI.hotpink_background/0","doc":"Sets background color to hotpink","ref":"Bunt.ANSI.html#hotpink_background/0"},{"type":"function","title":"Bunt.ANSI.inverse/0","doc":"Image: Negative. Swap foreground and background","ref":"Bunt.ANSI.html#inverse/0"},{"type":"function","title":"Bunt.ANSI.italic/0","doc":"Italic: on. Not widely supported. Sometimes treated as inverse","ref":"Bunt.ANSI.html#italic/0"},{"type":"function","title":"Bunt.ANSI.khaki/0","doc":"Sets foreground color to khaki","ref":"Bunt.ANSI.html#khaki/0"},{"type":"function","title":"Bunt.ANSI.khaki_background/0","doc":"Sets background color to khaki","ref":"Bunt.ANSI.html#khaki_background/0"},{"type":"function","title":"Bunt.ANSI.lightcyan/0","doc":"Sets foreground color to lightcyan","ref":"Bunt.ANSI.html#lightcyan/0"},{"type":"function","title":"Bunt.ANSI.lightcyan_background/0","doc":"Sets background color to lightcyan","ref":"Bunt.ANSI.html#lightcyan_background/0"},{"type":"function","title":"Bunt.ANSI.lightgray/0","doc":"Sets foreground color to lightgray","ref":"Bunt.ANSI.html#lightgray/0"},{"type":"function","title":"Bunt.ANSI.lightgray_background/0","doc":"Sets background color to lightgray","ref":"Bunt.ANSI.html#lightgray_background/0"},{"type":"function","title":"Bunt.ANSI.lightyellow/0","doc":"Sets foreground color to lightyellow","ref":"Bunt.ANSI.html#lightyellow/0"},{"type":"function","title":"Bunt.ANSI.lightyellow_background/0","doc":"Sets background color to lightyellow","ref":"Bunt.ANSI.html#lightyellow_background/0"},{"type":"function","title":"Bunt.ANSI.magenta/0","doc":"Sets foreground color to magenta","ref":"Bunt.ANSI.html#magenta/0"},{"type":"function","title":"Bunt.ANSI.magenta_background/0","doc":"Sets background color to magenta","ref":"Bunt.ANSI.html#magenta_background/0"},{"type":"function","title":"Bunt.ANSI.mediumblue/0","doc":"Sets foreground color to mediumblue","ref":"Bunt.ANSI.html#mediumblue/0"},{"type":"function","title":"Bunt.ANSI.mediumblue_background/0","doc":"Sets background color to mediumblue","ref":"Bunt.ANSI.html#mediumblue_background/0"},{"type":"function","title":"Bunt.ANSI.mistyrose/0","doc":"Sets foreground color to mistyrose","ref":"Bunt.ANSI.html#mistyrose/0"},{"type":"function","title":"Bunt.ANSI.mistyrose_background/0","doc":"Sets background color to mistyrose","ref":"Bunt.ANSI.html#mistyrose_background/0"},{"type":"function","title":"Bunt.ANSI.moccasin/0","doc":"Sets foreground color to moccasin","ref":"Bunt.ANSI.html#moccasin/0"},{"type":"function","title":"Bunt.ANSI.moccasin_background/0","doc":"Sets background color to moccasin","ref":"Bunt.ANSI.html#moccasin_background/0"},{"type":"function","title":"Bunt.ANSI.no_underline/0","doc":"Underline: None","ref":"Bunt.ANSI.html#no_underline/0"},{"type":"function","title":"Bunt.ANSI.normal/0","doc":"Normal color or intensity","ref":"Bunt.ANSI.html#normal/0"},{"type":"function","title":"Bunt.ANSI.not_framed_encircled/0","doc":"Not framed or encircled","ref":"Bunt.ANSI.html#not_framed_encircled/0"},{"type":"function","title":"Bunt.ANSI.not_italic/0","doc":"Not italic","ref":"Bunt.ANSI.html#not_italic/0"},{"type":"function","title":"Bunt.ANSI.not_overlined/0","doc":"Not overlined","ref":"Bunt.ANSI.html#not_overlined/0"},{"type":"function","title":"Bunt.ANSI.olive/0","doc":"Sets foreground color to olive","ref":"Bunt.ANSI.html#olive/0"},{"type":"function","title":"Bunt.ANSI.olive_background/0","doc":"Sets background color to olive","ref":"Bunt.ANSI.html#olive_background/0"},{"type":"function","title":"Bunt.ANSI.orange/0","doc":"Sets foreground color to orange","ref":"Bunt.ANSI.html#orange/0"},{"type":"function","title":"Bunt.ANSI.orange_background/0","doc":"Sets background color to orange","ref":"Bunt.ANSI.html#orange_background/0"},{"type":"function","title":"Bunt.ANSI.orangered/0","doc":"Sets foreground color to orangered","ref":"Bunt.ANSI.html#orangered/0"},{"type":"function","title":"Bunt.ANSI.orangered_background/0","doc":"Sets background color to orangered","ref":"Bunt.ANSI.html#orangered_background/0"},{"type":"function","title":"Bunt.ANSI.overlined/0","doc":"Overlined","ref":"Bunt.ANSI.html#overlined/0"},{"type":"function","title":"Bunt.ANSI.primary_font/0","doc":"Sets primary (default) font","ref":"Bunt.ANSI.html#primary_font/0"},{"type":"function","title":"Bunt.ANSI.red/0","doc":"Sets foreground color to red","ref":"Bunt.ANSI.html#red/0"},{"type":"function","title":"Bunt.ANSI.red_background/0","doc":"Sets background color to red","ref":"Bunt.ANSI.html#red_background/0"},{"type":"function","title":"Bunt.ANSI.reset/0","doc":"Resets all attributes","ref":"Bunt.ANSI.html#reset/0"},{"type":"function","title":"Bunt.ANSI.reverse/0","doc":"Image: Negative. Swap foreground and background","ref":"Bunt.ANSI.html#reverse/0"},{"type":"function","title":"Bunt.ANSI.springgreen/0","doc":"Sets foreground color to springgreen","ref":"Bunt.ANSI.html#springgreen/0"},{"type":"function","title":"Bunt.ANSI.springgreen_background/0","doc":"Sets background color to springgreen","ref":"Bunt.ANSI.html#springgreen_background/0"},{"type":"function","title":"Bunt.ANSI.steelblue/0","doc":"Sets foreground color to steelblue","ref":"Bunt.ANSI.html#steelblue/0"},{"type":"function","title":"Bunt.ANSI.steelblue_background/0","doc":"Sets background color to steelblue","ref":"Bunt.ANSI.html#steelblue_background/0"},{"type":"function","title":"Bunt.ANSI.underline/0","doc":"Underline: Single","ref":"Bunt.ANSI.html#underline/0"},{"type":"function","title":"Bunt.ANSI.white/0","doc":"Sets foreground color to white","ref":"Bunt.ANSI.html#white/0"},{"type":"function","title":"Bunt.ANSI.white_background/0","doc":"Sets background color to white","ref":"Bunt.ANSI.html#white_background/0"},{"type":"function","title":"Bunt.ANSI.yellow/0","doc":"Sets foreground color to yellow","ref":"Bunt.ANSI.html#yellow/0"},{"type":"function","title":"Bunt.ANSI.yellow_background/0","doc":"Sets background color to yellow","ref":"Bunt.ANSI.html#yellow_background/0"},{"type":"type","title":"Bunt.ANSI.ansidata/0","doc":"","ref":"Bunt.ANSI.html#t:ansidata/0"},{"type":"extras","title":"README","doc":"![Bunt](https://raw.github.com/rrrene/bunt/master/assets/logo.png)\n\nEnables 256 color ANSI coloring in the terminal and gives you the ability to alias colors to more semantic and application-specfic names.","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"It's available via Hex:\n\n  1. Add bunt to your list of dependencies in `mix.exs`:\n\n        def deps do\n          [{:bunt, \"~> 1.0\"}]\n        end\n\n  2. Ensure bunt is started before your application:\n\n        def application do\n          [extra_applications: [:bunt]]\n        end","ref":"readme.html#installation"},{"type":"extras","title":"Usage - README","doc":"#","ref":"readme.html#usage"},{"type":"extras","title":"256 colors - README","doc":"![Colors](https://raw.github.com/rrrene/bunt/master/assets/colors.png)\n\n`IO.ANSI` provides an interface to write text to the terminal in eight different colors like this:\n\n    [\"Hello, \", :red, :bright, \"world!\"]\n    |> IO.ANSI.format\n    |> IO.puts\n\nThis will put the word \"world!\" in bright red.\n\nTo cause as little friction as possible, the interface of `Bunt.ANSI` is 100% adapted from `IO.ANSI`.\n\nWe can use `Bunt` in the same way:\n\n    [\"Hello, \", :color202, :bright, \"world!\"]\n    |> Bunt.ANSI.format\n    |> IO.puts\n\nwhich puts a bright orange-red `\"world!\"` on the screen.\n\n`Bunt` also provides a shortcut so we can skip the `format` call.\n\n    [\"Hello, \", :color202, :bright, \"world!\"]\n    |> Bunt.puts\n\nand since nobody can remember that `:color202` is basically `:orangered`, you can use `:orangered` directly.\n\n\n\n#","ref":"readme.html#256-colors"},{"type":"extras","title":"Named colors - README","doc":"The following colors were given names, so you can use them in style:\n\n    [:gold, \"Look, it's really gold text!\"]\n    |> Bunt.puts\n\nReplace `:gold` with any of these values:\n\n    darkblue      mediumblue    darkgreen     darkslategray darkcyan\n    deepskyblue   springgreen   aqua          dimgray       steelblue\n    darkred       darkmagenta   olive         chartreuse    aquamarine\n    greenyellow   chocolate     goldenrod     lightgray     beige\n    lightcyan     fuchsia       orangered     hotpink       darkorange\n    coral         orange        gold          khaki         moccasin\n    mistyrose     lightyellow\n\nYou can see all supported colors by cloning the repo and running:\n\n    $ mix run script/colors.exs\n\n#","ref":"readme.html#named-colors"},{"type":"extras","title":"User-defined color aliases - README","doc":"But since all these colors are hard to remember, you can alias them in your config.exs:\n\n    # I tend to start the names of my color aliases with an underscore\n    # but this is, naturally, not a must.\n\n    config :bunt, color_aliases: [_cupcake: :color205]\n\nThen you can use these keys instead of the standard colors in your code:\n\n    [:_cupcake, \"Hello World!\"]\n    |> Bunt.puts\n\nUse this to give your colors semantics. They get easier to change later that way. (A colleague of mine shouted \"It's CSS for console applications!\" when he saw this and although that is ... well, not true, I really like the sentiment! :+1:)","ref":"readme.html#user-defined-color-aliases"},{"type":"extras","title":"Contributing - README","doc":"1. [Fork it!](http://github.com/rrrene/bunt/fork)\n2. Create your feature branch (`git checkout -b my-new-feature`)\n3. Commit your changes (`git commit -am 'Add some feature'`)\n4. Push to the branch (`git push origin my-new-feature`)\n5. Create new Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"Author - README","doc":"René Föhring (@rrrene)","ref":"readme.html#author"},{"type":"extras","title":"License - README","doc":"Bunt is released under the MIT License. See the LICENSE file for further\ndetails.\n\n\"Elixir\" and the Elixir logo are copyright (c) 2012 Plataformatec.\n\nElixir source code is released under Apache 2 License.\n\nCheck NOTICE, ELIXIR-LICENSE and LICENSE files for more information.","ref":"readme.html#license"}],"content_type":"text/markdown"}